Class: Google::Apis::ServicenetworkingV1::Aspect

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicenetworking_v1/classes.rb,
lib/google/apis/servicenetworking_v1/representations.rb,
lib/google/apis/servicenetworking_v1/representations.rb

Overview

Aspect represents Generic aspect. It is used to configure an aspect without making direct changes to service.proto

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Aspect

Returns a new instance of Aspect.



515
516
517
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 515

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kindString

The type of this aspect configuration. Corresponds to the JSON property kind

Returns:

  • (String)


502
503
504
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 502

def kind
  @kind
end

#rulesArray<Google::Apis::ServicenetworkingV1::AspectRule>

Optional. Rules of the Configuration. Corresponds to the JSON property rules



507
508
509
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 507

def rules
  @rules
end

#specHash<String,Object>

Content of the configuration. The underlying schema should be defined by Aspect owners as protobuf message under google/api/configaspects/proto. Corresponds to the JSON property spec

Returns:

  • (Hash<String,Object>)


513
514
515
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 513

def spec
  @spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



520
521
522
523
524
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 520

def update!(**args)
  @kind = args[:kind] if args.key?(:kind)
  @rules = args[:rules] if args.key?(:rules)
  @spec = args[:spec] if args.key?(:spec)
end