Class: Google::Apis::ServicenetworkingV1::BatchingDescriptorProto

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicenetworking_v1/classes.rb,
lib/google/apis/servicenetworking_v1/representations.rb,
lib/google/apis/servicenetworking_v1/representations.rb

Overview

BatchingDescriptorProto specifies the fields of the request message to be used for batching, and, optionally, the fields of the response message to be used for demultiplexing.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BatchingDescriptorProto

Returns a new instance of BatchingDescriptorProto.



900
901
902
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 900

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#batched_fieldString

The repeated field in the request message to be aggregated by batching. Corresponds to the JSON property batchedField

Returns:

  • (String)


884
885
886
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 884

def batched_field
  @batched_field
end

#discriminator_fieldsArray<String>

A list of the fields in the request message. Two requests will be batched together only if the values of every field specified in request_discriminator_fields is equal between the two requests. Corresponds to the JSON property discriminatorFields

Returns:

  • (Array<String>)


891
892
893
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 891

def discriminator_fields
  @discriminator_fields
end

#subresponse_fieldString

Optional. When present, indicates the field in the response message to be used to demultiplex the response into multiple response messages, in correspondence with the multiple request messages originally batched together. Corresponds to the JSON property subresponseField

Returns:

  • (String)


898
899
900
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 898

def subresponse_field
  @subresponse_field
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



905
906
907
908
909
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 905

def update!(**args)
  @batched_field = args[:batched_field] if args.key?(:batched_field)
  @discriminator_fields = args[:discriminator_fields] if args.key?(:discriminator_fields)
  @subresponse_field = args[:subresponse_field] if args.key?(:subresponse_field)
end