Class: Google::Apis::ServicenetworkingV1::ClientLibrarySettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicenetworking_v1/classes.rb,
lib/google/apis/servicenetworking_v1/representations.rb,
lib/google/apis/servicenetworking_v1/representations.rb

Overview

Details about how and where to publish client libraries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ClientLibrarySettings

Returns a new instance of ClientLibrarySettings.



1169
1170
1171
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1169

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cpp_settingsGoogle::Apis::ServicenetworkingV1::CppSettings

Settings for C++ client libraries. Corresponds to the JSON property cppSettings



1113
1114
1115
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1113

def cpp_settings
  @cpp_settings
end

#dotnet_settingsGoogle::Apis::ServicenetworkingV1::DotnetSettings

Settings for Dotnet client libraries. Corresponds to the JSON property dotnetSettings



1118
1119
1120
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1118

def dotnet_settings
  @dotnet_settings
end

#go_settingsGoogle::Apis::ServicenetworkingV1::GoSettings

Settings for Go client libraries. Corresponds to the JSON property goSettings



1123
1124
1125
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1123

def go_settings
  @go_settings
end

#java_settingsGoogle::Apis::ServicenetworkingV1::JavaSettings

Settings for Java client libraries. Corresponds to the JSON property javaSettings



1128
1129
1130
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1128

def java_settings
  @java_settings
end

#launch_stageString

Launch stage of this version of the API. Corresponds to the JSON property launchStage

Returns:

  • (String)


1133
1134
1135
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1133

def launch_stage
  @launch_stage
end

#node_settingsGoogle::Apis::ServicenetworkingV1::NodeSettings

Settings for Node client libraries. Corresponds to the JSON property nodeSettings



1138
1139
1140
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1138

def node_settings
  @node_settings
end

#php_settingsGoogle::Apis::ServicenetworkingV1::PhpSettings

Settings for Php client libraries. Corresponds to the JSON property phpSettings



1143
1144
1145
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1143

def php_settings
  @php_settings
end

#python_settingsGoogle::Apis::ServicenetworkingV1::PythonSettings

Settings for Python client libraries. Corresponds to the JSON property pythonSettings



1148
1149
1150
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1148

def python_settings
  @python_settings
end

#rest_numeric_enumsBoolean Also known as: rest_numeric_enums?

When using transport=rest, the client request will encode enums as numbers rather than strings. Corresponds to the JSON property restNumericEnums

Returns:

  • (Boolean)


1154
1155
1156
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1154

def rest_numeric_enums
  @rest_numeric_enums
end

#ruby_settingsGoogle::Apis::ServicenetworkingV1::RubySettings

Settings for Ruby client libraries. Corresponds to the JSON property rubySettings



1160
1161
1162
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1160

def ruby_settings
  @ruby_settings
end

#versionString

Version of the API to apply these settings to. This is the full protobuf package for the API, ending in the version element. Examples: "google.cloud. speech.v1" and "google.spanner.admin.database.v1". Corresponds to the JSON property version

Returns:

  • (String)


1167
1168
1169
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1167

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1174

def update!(**args)
  @cpp_settings = args[:cpp_settings] if args.key?(:cpp_settings)
  @dotnet_settings = args[:dotnet_settings] if args.key?(:dotnet_settings)
  @go_settings = args[:go_settings] if args.key?(:go_settings)
  @java_settings = args[:java_settings] if args.key?(:java_settings)
  @launch_stage = args[:launch_stage] if args.key?(:launch_stage)
  @node_settings = args[:node_settings] if args.key?(:node_settings)
  @php_settings = args[:php_settings] if args.key?(:php_settings)
  @python_settings = args[:python_settings] if args.key?(:python_settings)
  @rest_numeric_enums = args[:rest_numeric_enums] if args.key?(:rest_numeric_enums)
  @ruby_settings = args[:ruby_settings] if args.key?(:ruby_settings)
  @version = args[:version] if args.key?(:version)
end