Class: Google::Apis::ServicenetworkingV1::CloudSqlConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicenetworking_v1/classes.rb,
lib/google/apis/servicenetworking_v1/representations.rb,
lib/google/apis/servicenetworking_v1/representations.rb

Overview

Cloud SQL configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CloudSqlConfig

Returns a new instance of CloudSqlConfig.



1173
1174
1175
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1173

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#serviceString

Required. Peering service used for peering with the Cloud SQL project. Corresponds to the JSON property service

Returns:

  • (String)


1161
1162
1163
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1161

def service
  @service
end

#umbrella_networkString

Required. The name of the umbrella network in the Cloud SQL umbrella project. Corresponds to the JSON property umbrellaNetwork

Returns:

  • (String)


1166
1167
1168
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1166

def umbrella_network
  @umbrella_network
end

#umbrella_projectFixnum

Required. The project number of the Cloud SQL umbrella project. Corresponds to the JSON property umbrellaProject

Returns:

  • (Fixnum)


1171
1172
1173
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1171

def umbrella_project
  @umbrella_project
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1178
1179
1180
1181
1182
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1178

def update!(**args)
  @service = args[:service] if args.key?(:service)
  @umbrella_network = args[:umbrella_network] if args.key?(:umbrella_network)
  @umbrella_project = args[:umbrella_project] if args.key?(:umbrella_project)
end