Class: Google::Apis::ServicenetworkingV1::CommonLanguageSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicenetworking_v1/classes.rb,
lib/google/apis/servicenetworking_v1/representations.rb,
lib/google/apis/servicenetworking_v1/representations.rb

Overview

Required information for every language.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CommonLanguageSettings

Returns a new instance of CommonLanguageSettings.



1206
1207
1208
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1206

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destinationsArray<String>

The destination where API teams want this client library to be published. Corresponds to the JSON property destinations

Returns:

  • (Array<String>)


1192
1193
1194
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1192

def destinations
  @destinations
end

#reference_docs_uriString

Link to automatically generated reference documentation. Example: https:// cloud.google.com/nodejs/docs/reference/asset/latest Corresponds to the JSON property referenceDocsUri

Returns:

  • (String)


1198
1199
1200
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1198

def reference_docs_uri
  @reference_docs_uri
end

#selective_gapic_generationGoogle::Apis::ServicenetworkingV1::SelectiveGapicGeneration

This message is used to configure the generation of a subset of the RPCs in a service for client libraries. Corresponds to the JSON property selectiveGapicGeneration



1204
1205
1206
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1204

def selective_gapic_generation
  @selective_gapic_generation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1211
1212
1213
1214
1215
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1211

def update!(**args)
  @destinations = args[:destinations] if args.key?(:destinations)
  @reference_docs_uri = args[:reference_docs_uri] if args.key?(:reference_docs_uri)
  @selective_gapic_generation = args[:selective_gapic_generation] if args.key?(:selective_gapic_generation)
end