Class: Google::Apis::ServicenetworkingV1::ConsumerConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicenetworking_v1/classes.rb,
lib/google/apis/servicenetworking_v1/representations.rb,
lib/google/apis/servicenetworking_v1/representations.rb

Overview

Configuration information for a private service access connection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConsumerConfig

Returns a new instance of ConsumerConfig.



1397
1398
1399
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1397

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cloudsql_configsArray<Google::Apis::ServicenetworkingV1::CloudSqlConfig>

Represents one or multiple Cloud SQL configurations. Corresponds to the JSON property cloudsqlConfigs



1312
1313
1314
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1312

def cloudsql_configs
  @cloudsql_configs
end

#consumer_export_custom_routesBoolean Also known as: consumer_export_custom_routes?

Export custom routes flag value for peering from consumer to producer. Corresponds to the JSON property consumerExportCustomRoutes

Returns:

  • (Boolean)


1317
1318
1319
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1317

def consumer_export_custom_routes
  @consumer_export_custom_routes
end

#consumer_export_subnet_routes_with_public_ipBoolean Also known as: consumer_export_subnet_routes_with_public_ip?

Export subnet routes with public ip flag value for peering from consumer to producer. Corresponds to the JSON property consumerExportSubnetRoutesWithPublicIp

Returns:

  • (Boolean)


1324
1325
1326
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1324

def consumer_export_subnet_routes_with_public_ip
  @consumer_export_subnet_routes_with_public_ip
end

#consumer_import_custom_routesBoolean Also known as: consumer_import_custom_routes?

Import custom routes flag value for peering from consumer to producer. Corresponds to the JSON property consumerImportCustomRoutes

Returns:

  • (Boolean)


1330
1331
1332
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1330

def consumer_import_custom_routes
  @consumer_import_custom_routes
end

#consumer_import_subnet_routes_with_public_ipBoolean Also known as: consumer_import_subnet_routes_with_public_ip?

Import subnet routes with public ip flag value for peering from consumer to producer. Corresponds to the JSON property consumerImportSubnetRoutesWithPublicIp

Returns:

  • (Boolean)


1337
1338
1339
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1337

def consumer_import_subnet_routes_with_public_ip
  @consumer_import_subnet_routes_with_public_ip
end

#consumer_peering_activeBoolean Also known as: consumer_peering_active?

Output only. If this is true, consumer peering is active. Corresponds to the JSON property consumerPeeringActive

Returns:

  • (Boolean)


1343
1344
1345
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1343

def consumer_peering_active
  @consumer_peering_active
end

#producer_export_custom_routesBoolean Also known as: producer_export_custom_routes?

Export custom routes flag value for peering from producer to consumer. Corresponds to the JSON property producerExportCustomRoutes

Returns:

  • (Boolean)


1349
1350
1351
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1349

def producer_export_custom_routes
  @producer_export_custom_routes
end

#producer_export_subnet_routes_with_public_ipBoolean Also known as: producer_export_subnet_routes_with_public_ip?

Export subnet routes with public ip flag value for peering from producer to consumer. Corresponds to the JSON property producerExportSubnetRoutesWithPublicIp

Returns:

  • (Boolean)


1356
1357
1358
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1356

def producer_export_subnet_routes_with_public_ip
  @producer_export_subnet_routes_with_public_ip
end

#producer_import_custom_routesBoolean Also known as: producer_import_custom_routes?

Import custom routes flag value for peering from producer to consumer. Corresponds to the JSON property producerImportCustomRoutes

Returns:

  • (Boolean)


1362
1363
1364
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1362

def producer_import_custom_routes
  @producer_import_custom_routes
end

#producer_import_subnet_routes_with_public_ipBoolean Also known as: producer_import_subnet_routes_with_public_ip?

Import subnet routes with public ip flag value for peering from producer to consumer. Corresponds to the JSON property producerImportSubnetRoutesWithPublicIp

Returns:

  • (Boolean)


1369
1370
1371
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1369

def producer_import_subnet_routes_with_public_ip
  @producer_import_subnet_routes_with_public_ip
end

#producer_networkString

Output only. The VPC host network that is used to host managed service instances. In the format, projects/project/global/networks/network where project is the project number e.g. '12345' and network is the network name. Corresponds to the JSON property producerNetwork

Returns:

  • (String)


1377
1378
1379
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1377

def producer_network
  @producer_network
end

#reserved_rangesArray<Google::Apis::ServicenetworkingV1::GoogleCloudServicenetworkingV1ConsumerConfigReservedRange>

Output only. The reserved ranges associated with this private service access connection. Corresponds to the JSON property reservedRanges



1383
1384
1385
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1383

def reserved_ranges
  @reserved_ranges
end

#used_ip_rangesArray<String>

Output only. The IP ranges already in use by consumer or producer Corresponds to the JSON property usedIpRanges

Returns:

  • (Array<String>)


1388
1389
1390
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1388

def used_ip_ranges
  @used_ip_ranges
end

#vpc_sc_reference_architecture_enabledBoolean Also known as: vpc_sc_reference_architecture_enabled?

Output only. Indicates whether the VPC Service Controls reference architecture is configured for the producer VPC host network. Corresponds to the JSON property vpcScReferenceArchitectureEnabled

Returns:

  • (Boolean)


1394
1395
1396
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1394

def vpc_sc_reference_architecture_enabled
  @vpc_sc_reference_architecture_enabled
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
1413
1414
1415
1416
1417
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1402

def update!(**args)
  @cloudsql_configs = args[:cloudsql_configs] if args.key?(:cloudsql_configs)
  @consumer_export_custom_routes = args[:consumer_export_custom_routes] if args.key?(:consumer_export_custom_routes)
  @consumer_export_subnet_routes_with_public_ip = args[:consumer_export_subnet_routes_with_public_ip] if args.key?(:consumer_export_subnet_routes_with_public_ip)
  @consumer_import_custom_routes = args[:consumer_import_custom_routes] if args.key?(:consumer_import_custom_routes)
  @consumer_import_subnet_routes_with_public_ip = args[:consumer_import_subnet_routes_with_public_ip] if args.key?(:consumer_import_subnet_routes_with_public_ip)
  @consumer_peering_active = args[:consumer_peering_active] if args.key?(:consumer_peering_active)
  @producer_export_custom_routes = args[:producer_export_custom_routes] if args.key?(:producer_export_custom_routes)
  @producer_export_subnet_routes_with_public_ip = args[:producer_export_subnet_routes_with_public_ip] if args.key?(:producer_export_subnet_routes_with_public_ip)
  @producer_import_custom_routes = args[:producer_import_custom_routes] if args.key?(:producer_import_custom_routes)
  @producer_import_subnet_routes_with_public_ip = args[:producer_import_subnet_routes_with_public_ip] if args.key?(:producer_import_subnet_routes_with_public_ip)
  @producer_network = args[:producer_network] if args.key?(:producer_network)
  @reserved_ranges = args[:reserved_ranges] if args.key?(:reserved_ranges)
  @used_ip_ranges = args[:used_ip_ranges] if args.key?(:used_ip_ranges)
  @vpc_sc_reference_architecture_enabled = args[:vpc_sc_reference_architecture_enabled] if args.key?(:vpc_sc_reference_architecture_enabled)
end