Class: Google::Apis::ServicenetworkingV1::Endpoint
- Inherits:
-
Object
- Object
- Google::Apis::ServicenetworkingV1::Endpoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicenetworking_v1/classes.rb,
lib/google/apis/servicenetworking_v1/representations.rb,
lib/google/apis/servicenetworking_v1/representations.rb
Overview
Endpoint describes a network address of a service that serves a set of APIs.
It is commonly known as a service endpoint. A service may expose any number of
service endpoints, and all service endpoints share the same service definition,
such as quota limits and monitoring metrics. Example: type: google.api.
Service name: library-example.googleapis.com endpoints: # Declares network
address https://library-example.googleapis.com # for service library-
example.googleapis.com. The https scheme # is implicit for all service
endpoints. Other schemes may be # supported in the future. - name: library-
example.googleapis.com allow_cors: false - name: content-staging-library-
example.googleapis.com # Allows HTTP OPTIONS calls to be passed to the API
frontend, for it # to decide whether the subsequent cross-origin request is
allowed # to proceed. allow_cors: true
Instance Attribute Summary collapse
-
#aliases ⇒ Array<String>
Aliases for this endpoint, these will be served by the same UrlMap as the parent endpoint, and will be provisioned in the GCP stack for the Regional Endpoints.
-
#allow_cors ⇒ Boolean
(also: #allow_cors?)
Allowing CORS, aka cross-domain traffic, would allow the backends served from this endpoint to receive and respond to HTTP OPTIONS requests.
-
#name ⇒ String
The canonical name of this endpoint.
-
#target ⇒ String
The specification of an Internet routable address of API frontend that will handle requests to this API Endpoint.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Endpoint
constructor
A new instance of Endpoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Endpoint
Returns a new instance of Endpoint.
2115 2116 2117 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2115 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aliases ⇒ Array<String>
Aliases for this endpoint, these will be served by the same UrlMap as the
parent endpoint, and will be provisioned in the GCP stack for the Regional
Endpoints.
Corresponds to the JSON property aliases
2090 2091 2092 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2090 def aliases @aliases end |
#allow_cors ⇒ Boolean Also known as: allow_cors?
Allowing CORS,
aka cross-domain traffic, would allow the backends served from this endpoint
to receive and respond to HTTP OPTIONS requests. The response will be used by
the browser to determine whether the subsequent cross-origin request is
allowed to proceed.
Corresponds to the JSON property allowCors
2099 2100 2101 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2099 def allow_cors @allow_cors end |
#name ⇒ String
The canonical name of this endpoint.
Corresponds to the JSON property name
2105 2106 2107 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2105 def name @name end |
#target ⇒ String
The specification of an Internet routable address of API frontend that will
handle requests to this API Endpoint. It should be either a valid IPv4 address or a fully-qualified
domain name. For example, "8.8.8.8" or "myservice.appspot.com".
Corresponds to the JSON property target
2113 2114 2115 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2113 def target @target end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2120 2121 2122 2123 2124 2125 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2120 def update!(**args) @aliases = args[:aliases] if args.key?(:aliases) @allow_cors = args[:allow_cors] if args.key?(:allow_cors) @name = args[:name] if args.key?(:name) @target = args[:target] if args.key?(:target) end |