Class: Google::Apis::ServicenetworkingV1::Field

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicenetworking_v1/classes.rb,
lib/google/apis/servicenetworking_v1/representations.rb,
lib/google/apis/servicenetworking_v1/representations.rb

Overview

A single field of a message type. New usages of this message as an alternative to FieldDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Field

Returns a new instance of Field.



2321
2322
2323
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2321

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cardinalityString

The field cardinality. Corresponds to the JSON property cardinality

Returns:

  • (String)


2271
2272
2273
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2271

def cardinality
  @cardinality
end

#default_valueString

The string value of the default value of this field. Proto2 syntax only. Corresponds to the JSON property defaultValue

Returns:

  • (String)


2276
2277
2278
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2276

def default_value
  @default_value
end

#json_nameString

The field JSON name. Corresponds to the JSON property jsonName

Returns:

  • (String)


2281
2282
2283
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2281

def json_name
  @json_name
end

#kindString

The field type. Corresponds to the JSON property kind

Returns:

  • (String)


2286
2287
2288
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2286

def kind
  @kind
end

#nameString

The field name. Corresponds to the JSON property name

Returns:

  • (String)


2291
2292
2293
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2291

def name
  @name
end

#numberFixnum

The field number. Corresponds to the JSON property number

Returns:

  • (Fixnum)


2296
2297
2298
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2296

def number
  @number
end

#oneof_indexFixnum

The index of the field type in Type.oneofs, for message or enumeration types. The first type has index 1; zero means the type is not in the list. Corresponds to the JSON property oneofIndex

Returns:

  • (Fixnum)


2302
2303
2304
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2302

def oneof_index
  @oneof_index
end

#optionsArray<Google::Apis::ServicenetworkingV1::Option>

The protocol buffer options. Corresponds to the JSON property options



2307
2308
2309
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2307

def options
  @options
end

#packedBoolean Also known as: packed?

Whether to use alternative packed wire representation. Corresponds to the JSON property packed

Returns:

  • (Boolean)


2312
2313
2314
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2312

def packed
  @packed
end

#type_urlString

The field type URL, without the scheme, for message or enumeration types. Example: "type.googleapis.com/google.protobuf.Timestamp". Corresponds to the JSON property typeUrl

Returns:

  • (String)


2319
2320
2321
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2319

def type_url
  @type_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2326

def update!(**args)
  @cardinality = args[:cardinality] if args.key?(:cardinality)
  @default_value = args[:default_value] if args.key?(:default_value)
  @json_name = args[:json_name] if args.key?(:json_name)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @number = args[:number] if args.key?(:number)
  @oneof_index = args[:oneof_index] if args.key?(:oneof_index)
  @options = args[:options] if args.key?(:options)
  @packed = args[:packed] if args.key?(:packed)
  @type_url = args[:type_url] if args.key?(:type_url)
end