Class: Google::Apis::ServicenetworkingV1::FieldPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicenetworking_v1/classes.rb,
lib/google/apis/servicenetworking_v1/representations.rb,
lib/google/apis/servicenetworking_v1/representations.rb

Overview

Google API Policy Annotation This message defines a simple API policy annotation that can be used to annotate API request and response message fields with applicable policies. One field may have multiple applicable policies that must all be satisfied before a request can be processed. This policy annotation is used to generate the overall policy that will be used for automatic runtime policy enforcement and documentation generation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FieldPolicy

Returns a new instance of FieldPolicy.



2329
2330
2331
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2329

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#resource_permissionString

Specifies the required permission(s) for the resource referred to by the field. It requires the field contains a valid resource reference, and the request must pass the permission checks to proceed. For example, "resourcemanager. projects.get". Corresponds to the JSON property resourcePermission

Returns:

  • (String)


2312
2313
2314
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2312

def resource_permission
  @resource_permission
end

#resource_typeString

Specifies the resource type for the resource referred to by the field. Corresponds to the JSON property resourceType

Returns:

  • (String)


2317
2318
2319
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2317

def resource_type
  @resource_type
end

#selectorString

Selects one or more request or response message fields to apply this FieldPolicy. When a FieldPolicy is used in proto annotation, the selector must be left as empty. The service config generator will automatically fill the correct value. When a FieldPolicy is used in service config, the selector must be a comma-separated string with valid request or response field paths, such as "foo.bar" or "foo.bar,foo.baz". Corresponds to the JSON property selector

Returns:

  • (String)


2327
2328
2329
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2327

def selector
  @selector
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2334
2335
2336
2337
2338
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2334

def update!(**args)
  @resource_permission = args[:resource_permission] if args.key?(:resource_permission)
  @resource_type = args[:resource_type] if args.key?(:resource_type)
  @selector = args[:selector] if args.key?(:selector)
end