Class: Google::Apis::ServicenetworkingV1::GoSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicenetworking_v1/classes.rb,
lib/google/apis/servicenetworking_v1/representations.rb,
lib/google/apis/servicenetworking_v1/representations.rb

Overview

Settings for Go client libraries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoSettings

Returns a new instance of GoSettings.



2384
2385
2386
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2384

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#commonGoogle::Apis::ServicenetworkingV1::CommonLanguageSettings

Required information for every language. Corresponds to the JSON property common



2374
2375
2376
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2374

def common
  @common
end

#renamed_servicesHash<String,String>

Map of service names to renamed services. Keys are the package relative service names and values are the name to be used for the service client and call options. Example: publishing: go_settings: renamed_services: Publisher: TopicAdmin Corresponds to the JSON property renamedServices

Returns:

  • (Hash<String,String>)


2382
2383
2384
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2382

def renamed_services
  @renamed_services
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2389
2390
2391
2392
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2389

def update!(**args)
  @common = args[:common] if args.key?(:common)
  @renamed_services = args[:renamed_services] if args.key?(:renamed_services)
end