Class: Google::Apis::ServicenetworkingV1::GoogleCloudServicenetworkingV1betaSubnetwork

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicenetworking_v1/classes.rb,
lib/google/apis/servicenetworking_v1/representations.rb,
lib/google/apis/servicenetworking_v1/representations.rb

Overview

Represents a subnet that was created or discovered by a private access management service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudServicenetworkingV1betaSubnetwork

Returns a new instance of GoogleCloudServicenetworkingV1betaSubnetwork.



2547
2548
2549
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2547

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ip_cidr_rangeString

Subnetwork CIDR range in 10.x.x.x/y format. Corresponds to the JSON property ipCidrRange

Returns:

  • (String)


2527
2528
2529
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2527

def ip_cidr_range
  @ip_cidr_range
end

#nameString

Subnetwork name. See https://cloud.google.com/compute/docs/vpc/ Corresponds to the JSON property name

Returns:

  • (String)


2532
2533
2534
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2532

def name
  @name
end

#networkString

In the Shared VPC host project, the VPC network that's peered with the consumer network. For example: projects/1234321/global/networks/host-network Corresponds to the JSON property network

Returns:

  • (String)


2538
2539
2540
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2538

def network
  @network
end

#outside_allocationBoolean Also known as: outside_allocation?

This is a discovered subnet that is not within the current consumer allocated ranges. Corresponds to the JSON property outsideAllocation

Returns:

  • (Boolean)


2544
2545
2546
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2544

def outside_allocation
  @outside_allocation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2552
2553
2554
2555
2556
2557
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2552

def update!(**args)
  @ip_cidr_range = args[:ip_cidr_range] if args.key?(:ip_cidr_range)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @outside_allocation = args[:outside_allocation] if args.key?(:outside_allocation)
end