Class: Google::Apis::ServicenetworkingV1::MethodPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicenetworking_v1/classes.rb,
lib/google/apis/servicenetworking_v1/representations.rb,
lib/google/apis/servicenetworking_v1/representations.rb

Overview

Defines policies applying to an RPC method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MethodPolicy

Returns a new instance of MethodPolicy.



3229
3230
3231
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 3229

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#request_policiesArray<Google::Apis::ServicenetworkingV1::FieldPolicy>

Policies that are applicable to the request message. Corresponds to the JSON property requestPolicies



3219
3220
3221
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 3219

def request_policies
  @request_policies
end

#selectorString

Selects a method to which these policies should be enforced, for example, " google.pubsub.v1.Subscriber.CreateSubscription". Refer to selector for syntax details. NOTE: This field must not be set in the proto annotation. It will be automatically filled by the service config compiler . Corresponds to the JSON property selector

Returns:

  • (String)


3227
3228
3229
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 3227

def selector
  @selector
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3234
3235
3236
3237
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 3234

def update!(**args)
  @request_policies = args[:request_policies] if args.key?(:request_policies)
  @selector = args[:selector] if args.key?(:selector)
end