Class: Google::Apis::ServicenetworkingV1::MethodProp

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicenetworking_v1/classes.rb,
lib/google/apis/servicenetworking_v1/representations.rb,
lib/google/apis/servicenetworking_v1/representations.rb

Overview

Method represents a method of an API interface. New usages of this message as an alternative to MethodDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MethodProp

Returns a new instance of MethodProp.



3239
3240
3241
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 3239

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#editionString

The source edition string, only valid when syntax is SYNTAX_EDITIONS. This field should be ignored, instead the edition should be inherited from Api. This is similar to Field and EnumValue. Corresponds to the JSON property edition

Returns:

  • (String)


3199
3200
3201
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 3199

def edition
  @edition
end

#nameString

The simple name of this method. Corresponds to the JSON property name

Returns:

  • (String)


3204
3205
3206
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 3204

def name
  @name
end

#optionsArray<Google::Apis::ServicenetworkingV1::Option>

Any metadata attached to the method. Corresponds to the JSON property options



3209
3210
3211
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 3209

def options
  @options
end

#request_streamingBoolean Also known as: request_streaming?

If true, the request is streamed. Corresponds to the JSON property requestStreaming

Returns:

  • (Boolean)


3214
3215
3216
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 3214

def request_streaming
  @request_streaming
end

#request_type_urlString

A URL of the input message type. Corresponds to the JSON property requestTypeUrl

Returns:

  • (String)


3220
3221
3222
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 3220

def request_type_url
  @request_type_url
end

#response_streamingBoolean Also known as: response_streaming?

If true, the response is streamed. Corresponds to the JSON property responseStreaming

Returns:

  • (Boolean)


3225
3226
3227
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 3225

def response_streaming
  @response_streaming
end

#response_type_urlString

The URL of the output message type. Corresponds to the JSON property responseTypeUrl

Returns:

  • (String)


3231
3232
3233
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 3231

def response_type_url
  @response_type_url
end

#syntaxString

The source syntax of this method. This field should be ignored, instead the syntax should be inherited from Api. This is similar to Field and EnumValue. Corresponds to the JSON property syntax

Returns:

  • (String)


3237
3238
3239
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 3237

def syntax
  @syntax
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3244
3245
3246
3247
3248
3249
3250
3251
3252
3253
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 3244

def update!(**args)
  @edition = args[:edition] if args.key?(:edition)
  @name = args[:name] if args.key?(:name)
  @options = args[:options] if args.key?(:options)
  @request_streaming = args[:request_streaming] if args.key?(:request_streaming)
  @request_type_url = args[:request_type_url] if args.key?(:request_type_url)
  @response_streaming = args[:response_streaming] if args.key?(:response_streaming)
  @response_type_url = args[:response_type_url] if args.key?(:response_type_url)
  @syntax = args[:syntax] if args.key?(:syntax)
end