Class: Google::Apis::ServicenetworkingV1::PythonSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicenetworking_v1/classes.rb,
lib/google/apis/servicenetworking_v1/representations.rb,
lib/google/apis/servicenetworking_v1/representations.rb

Overview

Settings for Python client libraries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PythonSettings

Returns a new instance of PythonSettings.



4193
4194
4195
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4193

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#commonGoogle::Apis::ServicenetworkingV1::CommonLanguageSettings

Required information for every language. Corresponds to the JSON property common



4185
4186
4187
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4185

def common
  @common
end

#experimental_featuresGoogle::Apis::ServicenetworkingV1::ExperimentalFeatures

Experimental features to be included during client library generation. These fields will be deprecated once the feature graduates and is enabled by default. Corresponds to the JSON property experimentalFeatures



4191
4192
4193
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4191

def experimental_features
  @experimental_features
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4198
4199
4200
4201
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4198

def update!(**args)
  @common = args[:common] if args.key?(:common)
  @experimental_features = args[:experimental_features] if args.key?(:experimental_features)
end