Class: Google::Apis::ServicenetworkingV1::RemoveDnsRecordSetRequest
- Inherits:
-
Object
- Object
- Google::Apis::ServicenetworkingV1::RemoveDnsRecordSetRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicenetworking_v1/classes.rb,
lib/google/apis/servicenetworking_v1/representations.rb,
lib/google/apis/servicenetworking_v1/representations.rb
Overview
Request to remove a record set from a private managed DNS zone in the shared producer host project. The name, type, ttl, and data values must all exactly match an existing record set in the specified zone.
Instance Attribute Summary collapse
-
#consumer_network ⇒ String
Required.
-
#dns_record_set ⇒ Google::Apis::ServicenetworkingV1::DnsRecordSet
Represents a DNS record set resource.
-
#zone ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RemoveDnsRecordSetRequest
constructor
A new instance of RemoveDnsRecordSetRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RemoveDnsRecordSetRequest
Returns a new instance of RemoveDnsRecordSetRequest.
4451 4452 4453 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4451 def initialize(**args) update!(**args) end |
Instance Attribute Details
#consumer_network ⇒ String
Required. The network that the consumer is using to connect with services.
Must be in the form of projects/project/global/networks/network project
is the project number, as in '12345' network is the network name.
Corresponds to the JSON property consumerNetwork
4438 4439 4440 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4438 def consumer_network @consumer_network end |
#dns_record_set ⇒ Google::Apis::ServicenetworkingV1::DnsRecordSet
Represents a DNS record set resource.
Corresponds to the JSON property dnsRecordSet
4443 4444 4445 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4443 def dns_record_set @dns_record_set end |
#zone ⇒ String
Required. The name of the private DNS zone in the shared producer host project
from which the record set will be removed.
Corresponds to the JSON property zone
4449 4450 4451 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4449 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4456 4457 4458 4459 4460 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4456 def update!(**args) @consumer_network = args[:consumer_network] if args.key?(:consumer_network) @dns_record_set = args[:dns_record_set] if args.key?(:dns_record_set) @zone = args[:zone] if args.key?(:zone) end |