Class: Google::Apis::ServicenetworkingV1::SecondaryIpRangeSpec
- Inherits:
-
Object
- Object
- Google::Apis::ServicenetworkingV1::SecondaryIpRangeSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicenetworking_v1/classes.rb,
lib/google/apis/servicenetworking_v1/representations.rb,
lib/google/apis/servicenetworking_v1/representations.rb
Instance Attribute Summary collapse
-
#ip_prefix_length ⇒ Fixnum
Required.
-
#outside_allocation_public_ip_range ⇒ String
Optional.
-
#range_name ⇒ String
Required.
-
#requested_address ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecondaryIpRangeSpec
constructor
A new instance of SecondaryIpRangeSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecondaryIpRangeSpec
Returns a new instance of SecondaryIpRangeSpec.
4711 4712 4713 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4711 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ip_prefix_length ⇒ Fixnum
Required. The prefix length of the secondary IP range. Use CIDR range notation,
such as 30 to provision a secondary IP range with an x.x.x.x/30 CIDR
range. The IP address range is drawn from a pool of available ranges in the
service consumer's allocated range.
Corresponds to the JSON property ipPrefixLength
4687 4688 4689 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4687 def ip_prefix_length @ip_prefix_length end |
#outside_allocation_public_ip_range ⇒ String
Optional. Enable outside allocation using public IP addresses. Any public IP
range may be specified. If this field is provided, we will not use customer
reserved ranges for this secondary IP range.
Corresponds to the JSON property outsideAllocationPublicIpRange
4694 4695 4696 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4694 def outside_allocation_public_ip_range @outside_allocation_public_ip_range end |
#range_name ⇒ String
Required. A name for the secondary IP range. The name must be 1-63 characters
long, and comply with RFC1035. The name must be unique within the subnetwork.
Corresponds to the JSON property rangeName
4700 4701 4702 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4700 def range_name @range_name end |
#requested_address ⇒ String
Optional. The starting address of a range. The address must be a valid IPv4
address in the x.x.x.x format. This value combined with the IP prefix range is
the CIDR range for the secondary IP range. The range must be within the
allocated range that is assigned to the private connection. If the CIDR range
isn't available, the call fails.
Corresponds to the JSON property requestedAddress
4709 4710 4711 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4709 def requested_address @requested_address end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4716 4717 4718 4719 4720 4721 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4716 def update!(**args) @ip_prefix_length = args[:ip_prefix_length] if args.key?(:ip_prefix_length) @outside_allocation_public_ip_range = args[:outside_allocation_public_ip_range] if args.key?(:outside_allocation_public_ip_range) @range_name = args[:range_name] if args.key?(:range_name) @requested_address = args[:requested_address] if args.key?(:requested_address) end |