Class: Google::Apis::ServicenetworkingV1::Service

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicenetworking_v1/classes.rb,
lib/google/apis/servicenetworking_v1/representations.rb,
lib/google/apis/servicenetworking_v1/representations.rb

Overview

Service is the root object of Google API service configuration (service config). It describes the basic information about a logical service, such as the service name and the user-facing title, and delegates other aspects to sub- sections. Each sub-section is either a proto message or a repeated proto message that configures a specific aspect, such as auth. For more information, see each proto message definition. Example: type: google.api.Service name: calendar.googleapis.com title: Google Calendar API apis: - name: google. calendar.v3.Calendar visibility: rules: - selector: "google.calendar.v3." restriction: PREVIEW backend: rules: - selector: "google.calendar.v3." address: calendar.example.com authentication: providers: - id: google_calendar_auth jwks_uri: https://www.googleapis.com/oauth2/v1/certs issuer: https://securetoken.google.com rules: - selector: "*" requirements: provider_id: google_calendar_auth

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Service

Returns a new instance of Service.



5035
5036
5037
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 5035

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#apisArray<Google::Apis::ServicenetworkingV1::Api>

A list of API interfaces exported by this service. Only the name field of the google.protobuf.Api needs to be provided by the configuration author, as the remaining fields will be derived from the IDL during the normalization process. It is an error to specify an API interface here which cannot be resolved against the associated IDL files. Corresponds to the JSON property apis



4753
4754
4755
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4753

def apis
  @apis
end

#aspectsArray<Google::Apis::ServicenetworkingV1::Aspect>

Configuration aspects. This is a repeated field to allow multiple aspects to be configured. The kind field in each ConfigAspect specifies the type of aspect. The spec field contains the configuration for that aspect. The schema for the spec field is defined by the backend service owners. Corresponds to the JSON property aspects



4761
4762
4763
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4761

def aspects
  @aspects
end

#authenticationGoogle::Apis::ServicenetworkingV1::Authentication

Authentication defines the authentication configuration for API methods provided by an API service. Example: name: calendar.googleapis.com authentication: providers: - id: google_calendar_auth jwks_uri: https://www. googleapis.com/oauth2/v1/certs issuer: https://securetoken.google.com rules: - selector: "*" requirements: provider_id: google_calendar_auth - selector: google.calendar.Delegate oauth: canonical_scopes: https://www.googleapis.com/ auth/calendar.read Corresponds to the JSON property authentication



4772
4773
4774
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4772

def authentication
  @authentication
end

#backendGoogle::Apis::ServicenetworkingV1::Backend

Backend defines the backend configuration for a service. Corresponds to the JSON property backend



4777
4778
4779
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4777

def backend
  @backend
end

#billingGoogle::Apis::ServicenetworkingV1::Billing

Billing related configuration of the service. The following example shows how to configure monitored resources and metrics for billing, consumer_destinations is the only supported destination and the monitored resources need at least one label key cloud.googleapis.com/location to indicate the location of the billing usage, using different monitored resources between monitoring and billing is recommended so they can be evolved independently: monitored_resources: - type: library.googleapis.com/ billing_branch labels: - key: cloud.googleapis.com/location description: | Predefined label to support billing location restriction. - key: city description: | Custom label to define the city where the library branch is located in. - key: name description: Custom label to define the name of the library branch. metrics: - name: library.googleapis.com/book/borrowed_count metric_kind: DELTA value_type: INT64 unit: "1" billing: consumer_destinations:

  • monitored_resource: library.googleapis.com/billing_branch metrics: - library. googleapis.com/book/borrowed_count Corresponds to the JSON property billing


4796
4797
4798
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4796

def billing
  @billing
end

#config_versionFixnum

Obsolete. Do not use. This field has no semantic meaning. The service config compiler always sets this field to 3. Corresponds to the JSON property configVersion

Returns:

  • (Fixnum)


4802
4803
4804
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4802

def config_version
  @config_version
end

#contextGoogle::Apis::ServicenetworkingV1::Context

Context defines which contexts an API requests. Example: context: rules: - selector: "*" requested: - google.rpc.context.ProjectContext - google.rpc. context.OriginContext The above specifies that all methods in the API request google.rpc.context.ProjectContext and google.rpc.context.OriginContext. Available context types are defined in package google.rpc.context. This also provides mechanism to allowlist any protobuf message extension that can be sent in grpc metadata using “x-goog-ext--bin” and “x-goog-ext--jspb” format. For example, list any service specific protobuf types that can appear in grpc metadata as follows in your yaml file: Example: context: rules: - selector: " google.example.library.v1.LibraryService.CreateBook" allowed_request_extensions: - google.foo.v1.NewExtension allowed_response_extensions: - google.foo.v1.NewExtension You can also specify extension ID instead of fully qualified extension name here. Corresponds to the JSON property context



4819
4820
4821
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4819

def context
  @context
end

#controlGoogle::Apis::ServicenetworkingV1::Control

Selects and configures the service controller used by the service. Example: control: environment: servicecontrol.googleapis.com Corresponds to the JSON property control



4825
4826
4827
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4825

def control
  @control
end

#custom_errorGoogle::Apis::ServicenetworkingV1::CustomError

Customize service error responses. For example, list any service specific protobuf types that can appear in error detail lists of error responses. Example: custom_error: types: - google.foo.v1.CustomError - google.foo.v1. AnotherError Corresponds to the JSON property customError



4833
4834
4835
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4833

def custom_error
  @custom_error
end

#documentationGoogle::Apis::ServicenetworkingV1::Documentation

Documentation provides the information for describing a service. Example: documentation: summary: > The Google Calendar API gives access to most calendar features. pages: - name: Overview content: (== include google/foo/ overview.md ==) - name: Tutorial content: (== include google/foo/tutorial.md == ) subpages: - name: Java content: (== include google/foo/tutorial_java.md ==) rules: - selector: google.calendar.Calendar.Get description: > ... - selector: google.calendar.Calendar.Put description: > ... Documentation is provided in markdown syntax. In addition to standard markdown features, definition lists, tables and fenced code blocks are supported. Section headers can be provided and are interpreted relative to the section nesting of the context where a documentation fragment is embedded. Documentation from the IDL is merged with documentation defined via the config at normalization time, where documentation provided by config rules overrides IDL provided. A number of constructs specific to the API platform are supported in documentation text. In order to reference a proto element, the following notation can be used: [ fully.qualified.proto.name][] To override the display text used for the link, this can be used: [display text][fully.qualified.proto.name] Text can be excluded from doc using the following notation: (-- internal comment --) A few directives are available in documentation. Note that directives must appear on a single line to be properly identified. The include directive includes a markdown file from an external source: (== include path/to/file ==) The resource_for directive marks a message to be the resource of a collection in REST view. If it is not specified, tools attempt to infer the resource from the operations in a collection: (== resource_for v1.shelves.books ==) The directive suppress_warning does not directly affect documentation and is documented together with service config validation. Corresponds to the JSON property documentation



4863
4864
4865
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4863

def documentation
  @documentation
end

#endpointsArray<Google::Apis::ServicenetworkingV1::Endpoint>

Configuration for network endpoints. If this is empty, then an endpoint with the same name as the service is automatically generated to service all defined APIs. Corresponds to the JSON property endpoints



4870
4871
4872
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4870

def endpoints
  @endpoints
end

#enumsArray<Google::Apis::ServicenetworkingV1::Enum>

A list of all enum types included in this API service. Enums referenced directly or indirectly by the apis are automatically included. Enums which are not referenced but shall be included should be listed here by name by the configuration author. Example: enums: - name: google.someapi.v1.SomeEnum Corresponds to the JSON property enums



4878
4879
4880
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4878

def enums
  @enums
end

#httpGoogle::Apis::ServicenetworkingV1::Http

Defines the HTTP configuration for an API service. It contains a list of HttpRule, each specifying the mapping of an RPC method to one or more HTTP REST API methods. Corresponds to the JSON property http



4885
4886
4887
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4885

def http
  @http
end

#idString

A unique ID for a specific instance of this message, typically assigned by the client for tracking purpose. Must be no longer than 63 characters and only lower case letters, digits, '.', '_' and '-' are allowed. If empty, the server may choose to generate one instead. Corresponds to the JSON property id

Returns:

  • (String)


4893
4894
4895
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4893

def id
  @id
end

#loggingGoogle::Apis::ServicenetworkingV1::Logging

Logging configuration of the service. The following example shows how to configure logs to be sent to the producer and consumer projects. In the example, the activity_history log is sent to both the producer and consumer projects, whereas the purchase_history log is only sent to the producer project. monitored_resources: - type: library.googleapis.com/branch labels: - key: /city description: The city where the library branch is located in. - key: /name description: The name of the branch. logs: - name: activity_history labels: - key: /customer_id - name: purchase_history logging: producer_destinations: - monitored_resource: library.googleapis.com/branch logs: - activity_history - purchase_history consumer_destinations: - monitored_resource: library.googleapis.com/branch logs: - activity_history Corresponds to the JSON property logging



4908
4909
4910
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4908

def logging
  @logging
end

#logsArray<Google::Apis::ServicenetworkingV1::LogDescriptor>

Defines the logs used by this service. Corresponds to the JSON property logs



4913
4914
4915
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4913

def logs
  @logs
end

#metricsArray<Google::Apis::ServicenetworkingV1::MetricDescriptor>

Defines the metrics used by this service. Corresponds to the JSON property metrics



4918
4919
4920
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4918

def metrics
  @metrics
end

#monitored_resourcesArray<Google::Apis::ServicenetworkingV1::MonitoredResourceDescriptor>

Defines the monitored resources used by this service. This is required by the Service.monitoring and Service.logging configurations. Corresponds to the JSON property monitoredResources



4924
4925
4926
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4924

def monitored_resources
  @monitored_resources
end

#monitoringGoogle::Apis::ServicenetworkingV1::Monitoring

Monitoring configuration of the service. The example below shows how to configure monitored resources and metrics for monitoring. In the example, a monitored resource and two metrics are defined. The library.googleapis.com/ book/returned_count metric is sent to both producer and consumer projects, whereas the library.googleapis.com/book/num_overdue metric is only sent to the consumer project. monitored_resources: - type: library.googleapis.com/ Branch display_name: "Library Branch" description: "A branch of a library." launch_stage: GA labels: - key: resource_container description: "The Cloud container (ie. project id) for the Branch." - key: location description: "The location of the library branch." - key: branch_id description: "The id of the branch." metrics: - name: library.googleapis.com/book/returned_count display_name: "Books Returned" description: "The count of books that have been returned." launch_stage: GA metric_kind: DELTA value_type: INT64 unit: "1" labels: - key: customer_id description: "The id of the customer." - name: library.googleapis.com/book/num_overdue display_name: "Books Overdue" description: "The current number of overdue books." launch_stage: GA metric_kind: GAUGE value_type: INT64 unit: "1" labels: - key: customer_id description: "The id of the customer." monitoring: producer_destinations: - monitored_resource: library.googleapis.com/Branch metrics: - library. googleapis.com/book/returned_count consumer_destinations: - monitored_resource: library.googleapis.com/Branch metrics: - library.googleapis.com/book/ returned_count - library.googleapis.com/book/num_overdue Corresponds to the JSON property monitoring



4950
4951
4952
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4950

def monitoring
  @monitoring
end

#nameString

The service name, which is a DNS-like logical identifier for the service, such as calendar.googleapis.com. The service name typically goes through DNS verification to make sure the owner of the service also owns the DNS name. Corresponds to the JSON property name

Returns:

  • (String)


4957
4958
4959
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4957

def name
  @name
end

#producer_project_idString

The Google project that owns this service. Corresponds to the JSON property producerProjectId

Returns:

  • (String)


4962
4963
4964
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4962

def producer_project_id
  @producer_project_id
end

#publishingGoogle::Apis::ServicenetworkingV1::Publishing

This message configures the settings for publishing Google Cloud Client libraries generated from the service config. Corresponds to the JSON property publishing



4969
4970
4971
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4969

def publishing
  @publishing
end

#quotaGoogle::Apis::ServicenetworkingV1::Quota

Quota configuration helps to achieve fairness and budgeting in service usage. The metric based quota configuration works this way: - The service configuration defines a set of metrics. - For API calls, the quota. metric_rules maps methods to metrics with corresponding costs. - The quota. limits defines limits on the metrics, which will be used for quota checks at runtime. An example quota configuration in yaml format: quota: limits: - name: apiWriteQpsPerProject metric: library.googleapis.com/write_calls unit: "1/min/ project" # rate limit for consumer projects values: STANDARD: 10000 (The metric rules bind all methods to the read_calls metric, except for the UpdateBook and DeleteBook methods. These two methods are mapped to the write_calls metric, with the UpdateBook method consuming at twice rate as the DeleteBook method.) metric_rules: - selector: "*" metric_costs: library. googleapis.com/read_calls: 1 - selector: google.example.library.v1. LibraryService.UpdateBook metric_costs: library.googleapis.com/write_calls: 2 - selector: google.example.library.v1.LibraryService.DeleteBook metric_costs: library.googleapis.com/write_calls: 1 Corresponding Metric definition: metrics:

  • name: library.googleapis.com/read_calls display_name: Read requests metric_kind: DELTA value_type: INT64 - name: library.googleapis.com/ write_calls display_name: Write requests metric_kind: DELTA value_type: INT64 Corresponds to the JSON property quota


4992
4993
4994
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4992

def quota
  @quota
end

#source_infoGoogle::Apis::ServicenetworkingV1::SourceInfo

Source information used to create a Service Config Corresponds to the JSON property sourceInfo



4997
4998
4999
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4997

def source_info
  @source_info
end

#system_parametersGoogle::Apis::ServicenetworkingV1::SystemParameters

System parameter configuration A system parameter is a special kind of

parameter defined by the API system, not by an individual API. It is typically mapped to an HTTP header and/or a URL query parameter. This configuration specifies which methods change the names of the system parameters. Corresponds to the JSON property systemParameters



5005
5006
5007
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 5005

def system_parameters
  @system_parameters
end

#system_typesArray<Google::Apis::ServicenetworkingV1::Type>

A list of all proto message types included in this API service. It serves similar purpose as [google.api.Service.types], except that these types are not needed by user-defined APIs. Therefore, they will not show up in the generated discovery doc. This field should only be used to define system APIs in ESF. Corresponds to the JSON property systemTypes



5013
5014
5015
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 5013

def system_types
  @system_types
end

#titleString

The product title for this service, it is the name displayed in Google Cloud Console. Corresponds to the JSON property title

Returns:

  • (String)


5019
5020
5021
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 5019

def title
  @title
end

#typesArray<Google::Apis::ServicenetworkingV1::Type>

A list of all proto message types included in this API service. Types referenced directly or indirectly by the apis are automatically included. Messages which are not referenced but shall be included, such as types used by the google.protobuf.Any type, should be listed here by name by the configuration author. Example: types: - name: google.protobuf.Int32 Corresponds to the JSON property types



5028
5029
5030
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 5028

def types
  @types
end

#usageGoogle::Apis::ServicenetworkingV1::Usage

Configuration controlling usage of a service. Corresponds to the JSON property usage



5033
5034
5035
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 5033

def usage
  @usage
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5040
5041
5042
5043
5044
5045
5046
5047
5048
5049
5050
5051
5052
5053
5054
5055
5056
5057
5058
5059
5060
5061
5062
5063
5064
5065
5066
5067
5068
5069
5070
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 5040

def update!(**args)
  @apis = args[:apis] if args.key?(:apis)
  @aspects = args[:aspects] if args.key?(:aspects)
  @authentication = args[:authentication] if args.key?(:authentication)
  @backend = args[:backend] if args.key?(:backend)
  @billing = args[:billing] if args.key?(:billing)
  @config_version = args[:config_version] if args.key?(:config_version)
  @context = args[:context] if args.key?(:context)
  @control = args[:control] if args.key?(:control)
  @custom_error = args[:custom_error] if args.key?(:custom_error)
  @documentation = args[:documentation] if args.key?(:documentation)
  @endpoints = args[:endpoints] if args.key?(:endpoints)
  @enums = args[:enums] if args.key?(:enums)
  @http = args[:http] if args.key?(:http)
  @id = args[:id] if args.key?(:id)
  @logging = args[:logging] if args.key?(:logging)
  @logs = args[:logs] if args.key?(:logs)
  @metrics = args[:metrics] if args.key?(:metrics)
  @monitored_resources = args[:monitored_resources] if args.key?(:monitored_resources)
  @monitoring = args[:monitoring] if args.key?(:monitoring)
  @name = args[:name] if args.key?(:name)
  @producer_project_id = args[:producer_project_id] if args.key?(:producer_project_id)
  @publishing = args[:publishing] if args.key?(:publishing)
  @quota = args[:quota] if args.key?(:quota)
  @source_info = args[:source_info] if args.key?(:source_info)
  @system_parameters = args[:system_parameters] if args.key?(:system_parameters)
  @system_types = args[:system_types] if args.key?(:system_types)
  @title = args[:title] if args.key?(:title)
  @types = args[:types] if args.key?(:types)
  @usage = args[:usage] if args.key?(:usage)
end