Class: Google::Apis::ServicenetworkingV1::UpdateDnsRecordSetRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicenetworking_v1/classes.rb,
lib/google/apis/servicenetworking_v1/representations.rb,
lib/google/apis/servicenetworking_v1/representations.rb

Overview

Request to update a record set from a private managed DNS zone in the shared producer host project. The name, type, ttl, and data values of the existing record set must all exactly match an existing record set in the specified zone.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpdateDnsRecordSetRequest

Returns a new instance of UpdateDnsRecordSetRequest.



5423
5424
5425
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 5423

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#consumer_networkString

Required. The network that the consumer is using to connect with services. Must be in the form of projects/project/global/networks/network project is the project number, as in '12345' network is the network name. Corresponds to the JSON property consumerNetwork

Returns:

  • (String)


5405
5406
5407
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 5405

def consumer_network
  @consumer_network
end

#existing_dns_record_setGoogle::Apis::ServicenetworkingV1::DnsRecordSet

Represents a DNS record set resource. Corresponds to the JSON property existingDnsRecordSet



5410
5411
5412
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 5410

def existing_dns_record_set
  @existing_dns_record_set
end

#new_dns_record_setGoogle::Apis::ServicenetworkingV1::DnsRecordSet

Represents a DNS record set resource. Corresponds to the JSON property newDnsRecordSet



5415
5416
5417
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 5415

def new_dns_record_set
  @new_dns_record_set
end

#zoneString

Required. The name of the private DNS zone in the shared producer host project from which the record set will be removed. Corresponds to the JSON property zone

Returns:

  • (String)


5421
5422
5423
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 5421

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5428
5429
5430
5431
5432
5433
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 5428

def update!(**args)
  @consumer_network = args[:consumer_network] if args.key?(:consumer_network)
  @existing_dns_record_set = args[:existing_dns_record_set] if args.key?(:existing_dns_record_set)
  @new_dns_record_set = args[:new_dns_record_set] if args.key?(:new_dns_record_set)
  @zone = args[:zone] if args.key?(:zone)
end