Class: Google::Apis::ServicenetworkingV1::Aspect

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicenetworking_v1/classes.rb,
lib/google/apis/servicenetworking_v1/representations.rb,
lib/google/apis/servicenetworking_v1/representations.rb

Overview

Aspect represents Generic aspect. It is used to configure an aspect without making direct changes to service.proto

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Aspect

Returns a new instance of Aspect.



510
511
512
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 510

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kindString

The type of this aspect configuration. Corresponds to the JSON property kind

Returns:

  • (String)


502
503
504
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 502

def kind
  @kind
end

#specHash<String,Object>

Content of the configuration. The underlying schema should be defined by Aspect owners as protobuf message under google/api/configaspects/proto. Corresponds to the JSON property spec

Returns:

  • (Hash<String,Object>)


508
509
510
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 508

def spec
  @spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



515
516
517
518
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 515

def update!(**args)
  @kind = args[:kind] if args.key?(:kind)
  @spec = args[:spec] if args.key?(:spec)
end