Class: Google::Apis::ServicenetworkingV1::BatchingConfigProto

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicenetworking_v1/classes.rb,
lib/google/apis/servicenetworking_v1/representations.rb,
lib/google/apis/servicenetworking_v1/representations.rb

Overview

BatchingConfigProto defines the batching configuration for an API method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BatchingConfigProto

Returns a new instance of BatchingConfigProto.



864
865
866
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 864

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#batch_descriptorGoogle::Apis::ServicenetworkingV1::BatchingDescriptorProto

BatchingDescriptorProto specifies the fields of the request message to be used for batching, and, optionally, the fields of the response message to be used for demultiplexing. Corresponds to the JSON property batchDescriptor



855
856
857
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 855

def batch_descriptor
  @batch_descriptor
end

#thresholdsGoogle::Apis::ServicenetworkingV1::BatchingSettingsProto

BatchingSettingsProto specifies a set of batching thresholds, each of which acts as a trigger to send a batch of messages as a request. At least one threshold must be positive nonzero. Corresponds to the JSON property thresholds



862
863
864
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 862

def thresholds
  @thresholds
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



869
870
871
872
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 869

def update!(**args)
  @batch_descriptor = args[:batch_descriptor] if args.key?(:batch_descriptor)
  @thresholds = args[:thresholds] if args.key?(:thresholds)
end