Class: Google::Apis::ServicenetworkingV1::ClientLibrarySettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicenetworking_v1/classes.rb,
lib/google/apis/servicenetworking_v1/representations.rb,
lib/google/apis/servicenetworking_v1/representations.rb

Overview

Details about how and where to publish client libraries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ClientLibrarySettings

Returns a new instance of ClientLibrarySettings.



1134
1135
1136
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1134

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cpp_settingsGoogle::Apis::ServicenetworkingV1::CppSettings

Settings for C++ client libraries. Corresponds to the JSON property cppSettings



1078
1079
1080
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1078

def cpp_settings
  @cpp_settings
end

#dotnet_settingsGoogle::Apis::ServicenetworkingV1::DotnetSettings

Settings for Dotnet client libraries. Corresponds to the JSON property dotnetSettings



1083
1084
1085
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1083

def dotnet_settings
  @dotnet_settings
end

#go_settingsGoogle::Apis::ServicenetworkingV1::GoSettings

Settings for Go client libraries. Corresponds to the JSON property goSettings



1088
1089
1090
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1088

def go_settings
  @go_settings
end

#java_settingsGoogle::Apis::ServicenetworkingV1::JavaSettings

Settings for Java client libraries. Corresponds to the JSON property javaSettings



1093
1094
1095
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1093

def java_settings
  @java_settings
end

#launch_stageString

Launch stage of this version of the API. Corresponds to the JSON property launchStage

Returns:

  • (String)


1098
1099
1100
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1098

def launch_stage
  @launch_stage
end

#node_settingsGoogle::Apis::ServicenetworkingV1::NodeSettings

Settings for Node client libraries. Corresponds to the JSON property nodeSettings



1103
1104
1105
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1103

def node_settings
  @node_settings
end

#php_settingsGoogle::Apis::ServicenetworkingV1::PhpSettings

Settings for Php client libraries. Corresponds to the JSON property phpSettings



1108
1109
1110
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1108

def php_settings
  @php_settings
end

#python_settingsGoogle::Apis::ServicenetworkingV1::PythonSettings

Settings for Python client libraries. Corresponds to the JSON property pythonSettings



1113
1114
1115
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1113

def python_settings
  @python_settings
end

#rest_numeric_enumsBoolean Also known as: rest_numeric_enums?

When using transport=rest, the client request will encode enums as numbers rather than strings. Corresponds to the JSON property restNumericEnums

Returns:

  • (Boolean)


1119
1120
1121
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1119

def rest_numeric_enums
  @rest_numeric_enums
end

#ruby_settingsGoogle::Apis::ServicenetworkingV1::RubySettings

Settings for Ruby client libraries. Corresponds to the JSON property rubySettings



1125
1126
1127
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1125

def ruby_settings
  @ruby_settings
end

#versionString

Version of the API to apply these settings to. This is the full protobuf package for the API, ending in the version element. Examples: "google.cloud. speech.v1" and "google.spanner.admin.database.v1". Corresponds to the JSON property version

Returns:

  • (String)


1132
1133
1134
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1132

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1139

def update!(**args)
  @cpp_settings = args[:cpp_settings] if args.key?(:cpp_settings)
  @dotnet_settings = args[:dotnet_settings] if args.key?(:dotnet_settings)
  @go_settings = args[:go_settings] if args.key?(:go_settings)
  @java_settings = args[:java_settings] if args.key?(:java_settings)
  @launch_stage = args[:launch_stage] if args.key?(:launch_stage)
  @node_settings = args[:node_settings] if args.key?(:node_settings)
  @php_settings = args[:php_settings] if args.key?(:php_settings)
  @python_settings = args[:python_settings] if args.key?(:python_settings)
  @rest_numeric_enums = args[:rest_numeric_enums] if args.key?(:rest_numeric_enums)
  @ruby_settings = args[:ruby_settings] if args.key?(:ruby_settings)
  @version = args[:version] if args.key?(:version)
end