Class: Google::Apis::ServicenetworkingV1::ConsumerConfig
- Inherits:
-
Object
- Object
- Google::Apis::ServicenetworkingV1::ConsumerConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicenetworking_v1/classes.rb,
lib/google/apis/servicenetworking_v1/representations.rb,
lib/google/apis/servicenetworking_v1/representations.rb
Overview
Configuration information for a private service access connection.
Instance Attribute Summary collapse
-
#cloudsql_configs ⇒ Array<Google::Apis::ServicenetworkingV1::CloudSqlConfig>
Represents one or multiple Cloud SQL configurations.
-
#consumer_export_custom_routes ⇒ Boolean
(also: #consumer_export_custom_routes?)
Export custom routes flag value for peering from consumer to producer.
-
#consumer_export_subnet_routes_with_public_ip ⇒ Boolean
(also: #consumer_export_subnet_routes_with_public_ip?)
Export subnet routes with public ip flag value for peering from consumer to producer.
-
#consumer_import_custom_routes ⇒ Boolean
(also: #consumer_import_custom_routes?)
Import custom routes flag value for peering from consumer to producer.
-
#consumer_import_subnet_routes_with_public_ip ⇒ Boolean
(also: #consumer_import_subnet_routes_with_public_ip?)
Import subnet routes with public ip flag value for peering from consumer to producer.
-
#producer_export_custom_routes ⇒ Boolean
(also: #producer_export_custom_routes?)
Export custom routes flag value for peering from producer to consumer.
-
#producer_export_subnet_routes_with_public_ip ⇒ Boolean
(also: #producer_export_subnet_routes_with_public_ip?)
Export subnet routes with public ip flag value for peering from producer to consumer.
-
#producer_import_custom_routes ⇒ Boolean
(also: #producer_import_custom_routes?)
Import custom routes flag value for peering from producer to consumer.
-
#producer_import_subnet_routes_with_public_ip ⇒ Boolean
(also: #producer_import_subnet_routes_with_public_ip?)
Import subnet routes with public ip flag value for peering from producer to consumer.
-
#producer_network ⇒ String
Output only.
-
#reserved_ranges ⇒ Array<Google::Apis::ServicenetworkingV1::GoogleCloudServicenetworkingV1ConsumerConfigReservedRange>
Output only.
-
#used_ip_ranges ⇒ Array<String>
Output only.
-
#vpc_sc_reference_architecture_enabled ⇒ Boolean
(also: #vpc_sc_reference_architecture_enabled?)
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConsumerConfig
constructor
A new instance of ConsumerConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConsumerConfig
Returns a new instance of ConsumerConfig.
1355 1356 1357 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1355 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cloudsql_configs ⇒ Array<Google::Apis::ServicenetworkingV1::CloudSqlConfig>
Represents one or multiple Cloud SQL configurations.
Corresponds to the JSON property cloudsqlConfigs
1276 1277 1278 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1276 def cloudsql_configs @cloudsql_configs end |
#consumer_export_custom_routes ⇒ Boolean Also known as: consumer_export_custom_routes?
Export custom routes flag value for peering from consumer to producer.
Corresponds to the JSON property consumerExportCustomRoutes
1281 1282 1283 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1281 def consumer_export_custom_routes @consumer_export_custom_routes end |
#consumer_export_subnet_routes_with_public_ip ⇒ Boolean Also known as: consumer_export_subnet_routes_with_public_ip?
Export subnet routes with public ip flag value for peering from consumer to
producer.
Corresponds to the JSON property consumerExportSubnetRoutesWithPublicIp
1288 1289 1290 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1288 def consumer_export_subnet_routes_with_public_ip @consumer_export_subnet_routes_with_public_ip end |
#consumer_import_custom_routes ⇒ Boolean Also known as: consumer_import_custom_routes?
Import custom routes flag value for peering from consumer to producer.
Corresponds to the JSON property consumerImportCustomRoutes
1294 1295 1296 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1294 def consumer_import_custom_routes @consumer_import_custom_routes end |
#consumer_import_subnet_routes_with_public_ip ⇒ Boolean Also known as: consumer_import_subnet_routes_with_public_ip?
Import subnet routes with public ip flag value for peering from consumer to
producer.
Corresponds to the JSON property consumerImportSubnetRoutesWithPublicIp
1301 1302 1303 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1301 def consumer_import_subnet_routes_with_public_ip @consumer_import_subnet_routes_with_public_ip end |
#producer_export_custom_routes ⇒ Boolean Also known as: producer_export_custom_routes?
Export custom routes flag value for peering from producer to consumer.
Corresponds to the JSON property producerExportCustomRoutes
1307 1308 1309 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1307 def producer_export_custom_routes @producer_export_custom_routes end |
#producer_export_subnet_routes_with_public_ip ⇒ Boolean Also known as: producer_export_subnet_routes_with_public_ip?
Export subnet routes with public ip flag value for peering from producer to
consumer.
Corresponds to the JSON property producerExportSubnetRoutesWithPublicIp
1314 1315 1316 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1314 def producer_export_subnet_routes_with_public_ip @producer_export_subnet_routes_with_public_ip end |
#producer_import_custom_routes ⇒ Boolean Also known as: producer_import_custom_routes?
Import custom routes flag value for peering from producer to consumer.
Corresponds to the JSON property producerImportCustomRoutes
1320 1321 1322 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1320 def producer_import_custom_routes @producer_import_custom_routes end |
#producer_import_subnet_routes_with_public_ip ⇒ Boolean Also known as: producer_import_subnet_routes_with_public_ip?
Import subnet routes with public ip flag value for peering from producer to
consumer.
Corresponds to the JSON property producerImportSubnetRoutesWithPublicIp
1327 1328 1329 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1327 def producer_import_subnet_routes_with_public_ip @producer_import_subnet_routes_with_public_ip end |
#producer_network ⇒ String
Output only. The VPC host network that is used to host managed service
instances. In the format, projects/project/global/networks/network where
project is the project number e.g. '12345' and network is the network name.
Corresponds to the JSON property producerNetwork
1335 1336 1337 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1335 def producer_network @producer_network end |
#reserved_ranges ⇒ Array<Google::Apis::ServicenetworkingV1::GoogleCloudServicenetworkingV1ConsumerConfigReservedRange>
Output only. The reserved ranges associated with this private service access
connection.
Corresponds to the JSON property reservedRanges
1341 1342 1343 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1341 def reserved_ranges @reserved_ranges end |
#used_ip_ranges ⇒ Array<String>
Output only. The IP ranges already in use by consumer or producer
Corresponds to the JSON property usedIpRanges
1346 1347 1348 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1346 def used_ip_ranges @used_ip_ranges end |
#vpc_sc_reference_architecture_enabled ⇒ Boolean Also known as: vpc_sc_reference_architecture_enabled?
Output only. Indicates whether the VPC Service Controls reference architecture
is configured for the producer VPC host network.
Corresponds to the JSON property vpcScReferenceArchitectureEnabled
1352 1353 1354 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1352 def vpc_sc_reference_architecture_enabled @vpc_sc_reference_architecture_enabled end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1360 1361 1362 1363 1364 1365 1366 1367 1368 1369 1370 1371 1372 1373 1374 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1360 def update!(**args) @cloudsql_configs = args[:cloudsql_configs] if args.key?(:cloudsql_configs) @consumer_export_custom_routes = args[:consumer_export_custom_routes] if args.key?(:consumer_export_custom_routes) @consumer_export_subnet_routes_with_public_ip = args[:consumer_export_subnet_routes_with_public_ip] if args.key?(:consumer_export_subnet_routes_with_public_ip) @consumer_import_custom_routes = args[:consumer_import_custom_routes] if args.key?(:consumer_import_custom_routes) @consumer_import_subnet_routes_with_public_ip = args[:consumer_import_subnet_routes_with_public_ip] if args.key?(:consumer_import_subnet_routes_with_public_ip) @producer_export_custom_routes = args[:producer_export_custom_routes] if args.key?(:producer_export_custom_routes) @producer_export_subnet_routes_with_public_ip = args[:producer_export_subnet_routes_with_public_ip] if args.key?(:producer_export_subnet_routes_with_public_ip) @producer_import_custom_routes = args[:producer_import_custom_routes] if args.key?(:producer_import_custom_routes) @producer_import_subnet_routes_with_public_ip = args[:producer_import_subnet_routes_with_public_ip] if args.key?(:producer_import_subnet_routes_with_public_ip) @producer_network = args[:producer_network] if args.key?(:producer_network) @reserved_ranges = args[:reserved_ranges] if args.key?(:reserved_ranges) @used_ip_ranges = args[:used_ip_ranges] if args.key?(:used_ip_ranges) @vpc_sc_reference_architecture_enabled = args[:vpc_sc_reference_architecture_enabled] if args.key?(:vpc_sc_reference_architecture_enabled) end |