Class: Google::Apis::ServicenetworkingV1::CustomErrorRule
- Inherits:
-
Object
- Object
- Google::Apis::ServicenetworkingV1::CustomErrorRule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicenetworking_v1/classes.rb,
lib/google/apis/servicenetworking_v1/representations.rb,
lib/google/apis/servicenetworking_v1/representations.rb
Overview
A custom error rule.
Instance Attribute Summary collapse
-
#is_error_type ⇒ Boolean
(also: #is_error_type?)
Mark this message as possible payload in error response.
-
#selector ⇒ String
Selects messages to which this rule applies.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CustomErrorRule
constructor
A new instance of CustomErrorRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CustomErrorRule
Returns a new instance of CustomErrorRule.
1586 1587 1588 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1586 def initialize(**args) update!(**args) end |
Instance Attribute Details
#is_error_type ⇒ Boolean Also known as: is_error_type?
Mark this message as possible payload in error response. Otherwise, objects of
this type will be filtered when they appear in error payload.
Corresponds to the JSON property isErrorType
1577 1578 1579 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1577 def is_error_type @is_error_type end |
#selector ⇒ String
Selects messages to which this rule applies. Refer to selector for syntax
details.
Corresponds to the JSON property selector
1584 1585 1586 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1584 def selector @selector end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1591 1592 1593 1594 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1591 def update!(**args) @is_error_type = args[:is_error_type] if args.key?(:is_error_type) @selector = args[:selector] if args.key?(:selector) end |