Class: Google::Apis::ServicenetworkingV1::DotnetSettings
- Inherits:
-
Object
- Object
- Google::Apis::ServicenetworkingV1::DotnetSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicenetworking_v1/classes.rb,
lib/google/apis/servicenetworking_v1/representations.rb,
lib/google/apis/servicenetworking_v1/representations.rb
Overview
Settings for Dotnet client libraries.
Instance Attribute Summary collapse
-
#common ⇒ Google::Apis::ServicenetworkingV1::CommonLanguageSettings
Required information for every language.
-
#forced_namespace_aliases ⇒ Array<String>
Namespaces which must be aliased in snippets due to a known (but non-generator- predictable) naming collision Corresponds to the JSON property
forcedNamespaceAliases. -
#handwritten_signatures ⇒ Array<String>
Method signatures (in the form "service.method(signature)") which are provided separately, so shouldn't be generated.
-
#ignored_resources ⇒ Array<String>
List of full resource types to ignore during generation.
-
#renamed_resources ⇒ Hash<String,String>
Map from full resource types to the effective short name for the resource.
-
#renamed_services ⇒ Hash<String,String>
Map from original service names to renamed versions.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DotnetSettings
constructor
A new instance of DotnetSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DotnetSettings
Returns a new instance of DotnetSettings.
1975 1976 1977 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1975 def initialize(**args) update!(**args) end |
Instance Attribute Details
#common ⇒ Google::Apis::ServicenetworkingV1::CommonLanguageSettings
Required information for every language.
Corresponds to the JSON property common
1937 1938 1939 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1937 def common @common end |
#forced_namespace_aliases ⇒ Array<String>
Namespaces which must be aliased in snippets due to a known (but non-generator-
predictable) naming collision
Corresponds to the JSON property forcedNamespaceAliases
1943 1944 1945 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1943 def forced_namespace_aliases @forced_namespace_aliases end |
#handwritten_signatures ⇒ Array<String>
Method signatures (in the form "service.method(signature)") which are provided
separately, so shouldn't be generated. Snippets calling these methods are
still generated, however.
Corresponds to the JSON property handwrittenSignatures
1950 1951 1952 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1950 def handwritten_signatures @handwritten_signatures end |
#ignored_resources ⇒ Array<String>
List of full resource types to ignore during generation. This is typically
used for API-specific Location resources, which should be handled by the
generator as if they were actually the common Location resources. Example
entry: "documentai.googleapis.com/Location"
Corresponds to the JSON property ignoredResources
1958 1959 1960 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1958 def ignored_resources @ignored_resources end |
#renamed_resources ⇒ Hash<String,String>
Map from full resource types to the effective short name for the resource.
This is used when otherwise resource named from different services would cause
naming collisions. Example entry: "datalabeling.googleapis.com/Dataset": "
DataLabelingDataset"
Corresponds to the JSON property renamedResources
1966 1967 1968 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1966 def renamed_resources @renamed_resources end |
#renamed_services ⇒ Hash<String,String>
Map from original service names to renamed versions. This is used when the
default generated types would cause a naming conflict. (Neither name is fully-
qualified.) Example: Subscriber to SubscriberServiceApi.
Corresponds to the JSON property renamedServices
1973 1974 1975 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1973 def renamed_services @renamed_services end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1980 1981 1982 1983 1984 1985 1986 1987 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 1980 def update!(**args) @common = args[:common] if args.key?(:common) @forced_namespace_aliases = args[:forced_namespace_aliases] if args.key?(:forced_namespace_aliases) @handwritten_signatures = args[:handwritten_signatures] if args.key?(:handwritten_signatures) @ignored_resources = args[:ignored_resources] if args.key?(:ignored_resources) @renamed_resources = args[:renamed_resources] if args.key?(:renamed_resources) @renamed_services = args[:renamed_services] if args.key?(:renamed_services) end |