Class: Google::Apis::ServicenetworkingV1::Enum
- Inherits:
-
Object
- Object
- Google::Apis::ServicenetworkingV1::Enum
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicenetworking_v1/classes.rb,
lib/google/apis/servicenetworking_v1/representations.rb,
lib/google/apis/servicenetworking_v1/representations.rb
Overview
Enum type definition. New usages of this message as an alternative to EnumDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.
Instance Attribute Summary collapse
-
#edition ⇒ String
The source edition string, only valid when syntax is SYNTAX_EDITIONS.
-
#enumvalue ⇒ Array<Google::Apis::ServicenetworkingV1::EnumValue>
Enum value definitions.
-
#name ⇒ String
Enum type name.
-
#options ⇒ Array<Google::Apis::ServicenetworkingV1::Option>
Protocol buffer options.
-
#source_context ⇒ Google::Apis::ServicenetworkingV1::SourceContext
SourceContextrepresents information about the source of a protobuf element, like the file in which it is defined. -
#syntax ⇒ String
The source syntax.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Enum
constructor
A new instance of Enum.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Enum
Returns a new instance of Enum.
2167 2168 2169 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2167 def initialize(**args) update!(**args) end |
Instance Attribute Details
#edition ⇒ String
The source edition string, only valid when syntax is SYNTAX_EDITIONS.
Corresponds to the JSON property edition
2139 2140 2141 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2139 def edition @edition end |
#enumvalue ⇒ Array<Google::Apis::ServicenetworkingV1::EnumValue>
Enum value definitions.
Corresponds to the JSON property enumvalue
2144 2145 2146 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2144 def enumvalue @enumvalue end |
#name ⇒ String
Enum type name.
Corresponds to the JSON property name
2149 2150 2151 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2149 def name @name end |
#options ⇒ Array<Google::Apis::ServicenetworkingV1::Option>
Protocol buffer options.
Corresponds to the JSON property options
2154 2155 2156 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2154 def @options end |
#source_context ⇒ Google::Apis::ServicenetworkingV1::SourceContext
SourceContext represents information about the source of a protobuf element,
like the file in which it is defined.
Corresponds to the JSON property sourceContext
2160 2161 2162 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2160 def source_context @source_context end |
#syntax ⇒ String
The source syntax.
Corresponds to the JSON property syntax
2165 2166 2167 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2165 def syntax @syntax end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2172 2173 2174 2175 2176 2177 2178 2179 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2172 def update!(**args) @edition = args[:edition] if args.key?(:edition) @enumvalue = args[:enumvalue] if args.key?(:enumvalue) @name = args[:name] if args.key?(:name) @options = args[:options] if args.key?(:options) @source_context = args[:source_context] if args.key?(:source_context) @syntax = args[:syntax] if args.key?(:syntax) end |