Class: Google::Apis::ServicenetworkingV1::Enum
- Inherits:
-
Object
- Object
- Google::Apis::ServicenetworkingV1::Enum
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicenetworking_v1/classes.rb,
lib/google/apis/servicenetworking_v1/representations.rb,
lib/google/apis/servicenetworking_v1/representations.rb
Overview
Enum type definition. New usages of this message as an alternative to EnumDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.
Instance Attribute Summary collapse
-
#edition ⇒ String
The source edition string, only valid when syntax is SYNTAX_EDITIONS.
-
#enumvalue ⇒ Array<Google::Apis::ServicenetworkingV1::EnumValue>
Enum value definitions.
-
#name ⇒ String
Enum type name.
-
#options ⇒ Array<Google::Apis::ServicenetworkingV1::Option>
Protocol buffer options.
-
#source_context ⇒ Google::Apis::ServicenetworkingV1::SourceContext
SourceContextrepresents information about the source of a protobuf element, like the file in which it is defined. -
#syntax ⇒ String
The source syntax.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Enum
constructor
A new instance of Enum.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Enum
Returns a new instance of Enum.
2124 2125 2126 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2124 def initialize(**args) update!(**args) end |
Instance Attribute Details
#edition ⇒ String
The source edition string, only valid when syntax is SYNTAX_EDITIONS.
Corresponds to the JSON property edition
2096 2097 2098 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2096 def edition @edition end |
#enumvalue ⇒ Array<Google::Apis::ServicenetworkingV1::EnumValue>
Enum value definitions.
Corresponds to the JSON property enumvalue
2101 2102 2103 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2101 def enumvalue @enumvalue end |
#name ⇒ String
Enum type name.
Corresponds to the JSON property name
2106 2107 2108 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2106 def name @name end |
#options ⇒ Array<Google::Apis::ServicenetworkingV1::Option>
Protocol buffer options.
Corresponds to the JSON property options
2111 2112 2113 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2111 def @options end |
#source_context ⇒ Google::Apis::ServicenetworkingV1::SourceContext
SourceContext represents information about the source of a protobuf element,
like the file in which it is defined.
Corresponds to the JSON property sourceContext
2117 2118 2119 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2117 def source_context @source_context end |
#syntax ⇒ String
The source syntax.
Corresponds to the JSON property syntax
2122 2123 2124 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2122 def syntax @syntax end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2129 2130 2131 2132 2133 2134 2135 2136 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2129 def update!(**args) @edition = args[:edition] if args.key?(:edition) @enumvalue = args[:enumvalue] if args.key?(:enumvalue) @name = args[:name] if args.key?(:name) @options = args[:options] if args.key?(:options) @source_context = args[:source_context] if args.key?(:source_context) @syntax = args[:syntax] if args.key?(:syntax) end |