Class: Google::Apis::ServicenetworkingV1::EnumValue
- Inherits:
-
Object
- Object
- Google::Apis::ServicenetworkingV1::EnumValue
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicenetworking_v1/classes.rb,
lib/google/apis/servicenetworking_v1/representations.rb,
lib/google/apis/servicenetworking_v1/representations.rb
Overview
Enum value definition. New usages of this message as an alternative to EnumValueDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.
Instance Attribute Summary collapse
-
#name ⇒ String
Enum value name.
-
#number ⇒ Fixnum
Enum value number.
-
#options ⇒ Array<Google::Apis::ServicenetworkingV1::Option>
Protocol buffer options.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EnumValue
constructor
A new instance of EnumValue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EnumValue
Returns a new instance of EnumValue.
2205 2206 2207 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2205 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Enum value name.
Corresponds to the JSON property name
2193 2194 2195 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2193 def name @name end |
#number ⇒ Fixnum
Enum value number.
Corresponds to the JSON property number
2198 2199 2200 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2198 def number @number end |
#options ⇒ Array<Google::Apis::ServicenetworkingV1::Option>
Protocol buffer options.
Corresponds to the JSON property options
2203 2204 2205 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2203 def @options end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2210 2211 2212 2213 2214 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2210 def update!(**args) @name = args[:name] if args.key?(:name) @number = args[:number] if args.key?(:number) @options = args[:options] if args.key?(:options) end |