Class: Google::Apis::ServicenetworkingV1::EnumValue

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicenetworking_v1/classes.rb,
lib/google/apis/servicenetworking_v1/representations.rb,
lib/google/apis/servicenetworking_v1/representations.rb

Overview

Enum value definition. New usages of this message as an alternative to EnumValueDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EnumValue

Returns a new instance of EnumValue.



2162
2163
2164
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2162

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Enum value name. Corresponds to the JSON property name

Returns:

  • (String)


2150
2151
2152
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2150

def name
  @name
end

#numberFixnum

Enum value number. Corresponds to the JSON property number

Returns:

  • (Fixnum)


2155
2156
2157
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2155

def number
  @number
end

#optionsArray<Google::Apis::ServicenetworkingV1::Option>

Protocol buffer options. Corresponds to the JSON property options



2160
2161
2162
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2160

def options
  @options
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2167
2168
2169
2170
2171
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 2167

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @number = args[:number] if args.key?(:number)
  @options = args[:options] if args.key?(:options)
end