Class: Google::Apis::ServicenetworkingV1::MethodProp

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicenetworking_v1/classes.rb,
lib/google/apis/servicenetworking_v1/representations.rb,
lib/google/apis/servicenetworking_v1/representations.rb

Overview

Method represents a method of an API interface. New usages of this message as an alternative to MethodDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MethodProp

Returns a new instance of MethodProp.



3195
3196
3197
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 3195

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#editionString

The source edition string, only valid when syntax is SYNTAX_EDITIONS. This field should be ignored, instead the edition should be inherited from Api. This is similar to Field and EnumValue. Corresponds to the JSON property edition

Returns:

  • (String)


3155
3156
3157
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 3155

def edition
  @edition
end

#nameString

The simple name of this method. Corresponds to the JSON property name

Returns:

  • (String)


3160
3161
3162
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 3160

def name
  @name
end

#optionsArray<Google::Apis::ServicenetworkingV1::Option>

Any metadata attached to the method. Corresponds to the JSON property options



3165
3166
3167
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 3165

def options
  @options
end

#request_streamingBoolean Also known as: request_streaming?

If true, the request is streamed. Corresponds to the JSON property requestStreaming

Returns:

  • (Boolean)


3170
3171
3172
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 3170

def request_streaming
  @request_streaming
end

#request_type_urlString

A URL of the input message type. Corresponds to the JSON property requestTypeUrl

Returns:

  • (String)


3176
3177
3178
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 3176

def request_type_url
  @request_type_url
end

#response_streamingBoolean Also known as: response_streaming?

If true, the response is streamed. Corresponds to the JSON property responseStreaming

Returns:

  • (Boolean)


3181
3182
3183
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 3181

def response_streaming
  @response_streaming
end

#response_type_urlString

The URL of the output message type. Corresponds to the JSON property responseTypeUrl

Returns:

  • (String)


3187
3188
3189
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 3187

def response_type_url
  @response_type_url
end

#syntaxString

The source syntax of this method. This field should be ignored, instead the syntax should be inherited from Api. This is similar to Field and EnumValue. Corresponds to the JSON property syntax

Returns:

  • (String)


3193
3194
3195
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 3193

def syntax
  @syntax
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3200
3201
3202
3203
3204
3205
3206
3207
3208
3209
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 3200

def update!(**args)
  @edition = args[:edition] if args.key?(:edition)
  @name = args[:name] if args.key?(:name)
  @options = args[:options] if args.key?(:options)
  @request_streaming = args[:request_streaming] if args.key?(:request_streaming)
  @request_type_url = args[:request_type_url] if args.key?(:request_type_url)
  @response_streaming = args[:response_streaming] if args.key?(:response_streaming)
  @response_type_url = args[:response_type_url] if args.key?(:response_type_url)
  @syntax = args[:syntax] if args.key?(:syntax)
end