Class: Google::Apis::ServicenetworkingV1::MetricRule
- Inherits:
-
Object
- Object
- Google::Apis::ServicenetworkingV1::MetricRule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicenetworking_v1/classes.rb,
lib/google/apis/servicenetworking_v1/representations.rb,
lib/google/apis/servicenetworking_v1/representations.rb
Overview
Bind API methods to metrics. Binding a method to a metric causes that metric's configured quota behaviors to apply to the method call.
Instance Attribute Summary collapse
-
#agentic_metric_costs ⇒ Hash<String,Fixnum>
Optional.
-
#metric_costs ⇒ Hash<String,Fixnum>
Metrics to update when the selected methods are called, and the associated cost applied to each metric.
-
#nonagentic_metric_costs ⇒ Hash<String,Fixnum>
Optional.
-
#selector ⇒ String
Selects the methods to which this rule applies.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MetricRule
constructor
A new instance of MetricRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MetricRule
Returns a new instance of MetricRule.
3554 3555 3556 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 3554 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agentic_metric_costs ⇒ Hash<String,Fixnum>
Optional. Metrics to update when the selected methods are called, and the
associated cost applied to each metric, iff the source of the call is an agent.
The key of the map is the metric name, and the values are the amount
increased for the metric against which the quota limits are defined. The value
must not be negative.
Corresponds to the JSON property agenticMetricCosts
3529 3530 3531 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 3529 def agentic_metric_costs @agentic_metric_costs end |
#metric_costs ⇒ Hash<String,Fixnum>
Metrics to update when the selected methods are called, and the associated
cost applied to each metric. The key of the map is the metric name, and the
values are the amount increased for the metric against which the quota limits
are defined. The value must not be negative.
Corresponds to the JSON property metricCosts
3537 3538 3539 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 3537 def metric_costs @metric_costs end |
#nonagentic_metric_costs ⇒ Hash<String,Fixnum>
Optional. Metrics to update when the selected methods are called, and the
associated cost applied to each metric, iff the source of the call is not an
agent. The key of the map is the metric name, and the values are the amount
increased for the metric against which the quota limits are defined. The value
must not be negative.
Corresponds to the JSON property nonagenticMetricCosts
3546 3547 3548 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 3546 def nonagentic_metric_costs @nonagentic_metric_costs end |
#selector ⇒ String
Selects the methods to which this rule applies. Refer to selector for syntax
details.
Corresponds to the JSON property selector
3552 3553 3554 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 3552 def selector @selector end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3559 3560 3561 3562 3563 3564 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 3559 def update!(**args) @agentic_metric_costs = args[:agentic_metric_costs] if args.key?(:agentic_metric_costs) @metric_costs = args[:metric_costs] if args.key?(:metric_costs) @nonagentic_metric_costs = args[:nonagentic_metric_costs] if args.key?(:nonagentic_metric_costs) @selector = args[:selector] if args.key?(:selector) end |