Class: Google::Apis::ServicenetworkingV1::PythonSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicenetworking_v1/classes.rb,
lib/google/apis/servicenetworking_v1/representations.rb,
lib/google/apis/servicenetworking_v1/representations.rb

Overview

Settings for Python client libraries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PythonSettings

Returns a new instance of PythonSettings.



4129
4130
4131
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4129

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#commonGoogle::Apis::ServicenetworkingV1::CommonLanguageSettings

Required information for every language. Corresponds to the JSON property common



4121
4122
4123
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4121

def common
  @common
end

#experimental_featuresGoogle::Apis::ServicenetworkingV1::ExperimentalFeatures

Experimental features to be included during client library generation. These fields will be deprecated once the feature graduates and is enabled by default. Corresponds to the JSON property experimentalFeatures



4127
4128
4129
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4127

def experimental_features
  @experimental_features
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4134
4135
4136
4137
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4134

def update!(**args)
  @common = args[:common] if args.key?(:common)
  @experimental_features = args[:experimental_features] if args.key?(:experimental_features)
end