Class: Google::Apis::ServicenetworkingV1::RangeReservation
- Inherits:
-
Object
- Object
- Google::Apis::ServicenetworkingV1::RangeReservation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicenetworking_v1/classes.rb,
lib/google/apis/servicenetworking_v1/representations.rb,
lib/google/apis/servicenetworking_v1/representations.rb
Overview
Represents a range reservation.
Instance Attribute Summary collapse
-
#ip_prefix_length ⇒ Fixnum
Required.
-
#requested_ranges ⇒ Array<String>
Optional.
-
#secondary_range_ip_prefix_lengths ⇒ Array<Fixnum>
Optional.
-
#subnetwork_candidates ⇒ Array<Google::Apis::ServicenetworkingV1::Subnetwork>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RangeReservation
constructor
A new instance of RangeReservation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RangeReservation
Returns a new instance of RangeReservation.
4356 4357 4358 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4356 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ip_prefix_length ⇒ Fixnum
Required. The size of the desired subnet. Use usual CIDR range notation. For
example, '29' to find unused x.x.x.x/29 CIDR range. The goal is to determine
if one of the allocated ranges has enough free space for a subnet of the
requested size. GCE disallows subnets with prefix_length > 29
Corresponds to the JSON property ipPrefixLength
4328 4329 4330 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4328 def ip_prefix_length @ip_prefix_length end |
#requested_ranges ⇒ Array<String>
Optional. The name of one or more allocated IP address ranges associated with
this private service access connection. If no range names are provided all
ranges associated with this connection will be considered. If a CIDR range
with the specified IP prefix length is not available within these ranges the
validation fails.
Corresponds to the JSON property requestedRanges
4337 4338 4339 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4337 def requested_ranges @requested_ranges end |
#secondary_range_ip_prefix_lengths ⇒ Array<Fixnum>
Optional. The size of the desired secondary ranges for the subnet. Use usual
CIDR range notation. For example, '29' to find unused x.x.x.x/29 CIDR range.
The goal is to determine that the allocated ranges have enough free space for
all the requested secondary ranges. GCE disallows subnets with prefix_length >
29
Corresponds to the JSON property secondaryRangeIpPrefixLengths
4346 4347 4348 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4346 def secondary_range_ip_prefix_lengths @secondary_range_ip_prefix_lengths end |
#subnetwork_candidates ⇒ Array<Google::Apis::ServicenetworkingV1::Subnetwork>
Optional. List of subnetwork candidates to validate. The required input fields
are name, network, and region. Subnetworks from this list which exist
will be returned in the response with the ip_cidr_range,
secondary_ip_cider_ranges, and outside_allocation fields set.
Corresponds to the JSON property subnetworkCandidates
4354 4355 4356 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4354 def subnetwork_candidates @subnetwork_candidates end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4361 4362 4363 4364 4365 4366 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4361 def update!(**args) @ip_prefix_length = args[:ip_prefix_length] if args.key?(:ip_prefix_length) @requested_ranges = args[:requested_ranges] if args.key?(:requested_ranges) @secondary_range_ip_prefix_lengths = args[:secondary_range_ip_prefix_lengths] if args.key?(:secondary_range_ip_prefix_lengths) @subnetwork_candidates = args[:subnetwork_candidates] if args.key?(:subnetwork_candidates) end |