Class: Google::Apis::ServicenetworkingV1::RemoveDnsRecordSetRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicenetworking_v1/classes.rb,
lib/google/apis/servicenetworking_v1/representations.rb,
lib/google/apis/servicenetworking_v1/representations.rb

Overview

Request to remove a record set from a private managed DNS zone in the shared producer host project. The name, type, ttl, and data values must all exactly match an existing record set in the specified zone.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RemoveDnsRecordSetRequest

Returns a new instance of RemoveDnsRecordSetRequest.



4407
4408
4409
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4407

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#consumer_networkString

Required. The network that the consumer is using to connect with services. Must be in the form of projects/project/global/networks/network project is the project number, as in '12345' network is the network name. Corresponds to the JSON property consumerNetwork

Returns:

  • (String)


4394
4395
4396
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4394

def consumer_network
  @consumer_network
end

#dns_record_setGoogle::Apis::ServicenetworkingV1::DnsRecordSet

Represents a DNS record set resource. Corresponds to the JSON property dnsRecordSet



4399
4400
4401
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4399

def dns_record_set
  @dns_record_set
end

#zoneString

Required. The name of the private DNS zone in the shared producer host project from which the record set will be removed. Corresponds to the JSON property zone

Returns:

  • (String)


4405
4406
4407
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4405

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4412
4413
4414
4415
4416
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4412

def update!(**args)
  @consumer_network = args[:consumer_network] if args.key?(:consumer_network)
  @dns_record_set = args[:dns_record_set] if args.key?(:dns_record_set)
  @zone = args[:zone] if args.key?(:zone)
end