Class: Google::Apis::ServicenetworkingV1::RemoveDnsZoneRequest
- Inherits:
-
Object
- Object
- Google::Apis::ServicenetworkingV1::RemoveDnsZoneRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicenetworking_v1/classes.rb,
lib/google/apis/servicenetworking_v1/representations.rb,
lib/google/apis/servicenetworking_v1/representations.rb
Overview
Request to remove a private managed DNS zone in the shared producer host project and a matching DNS peering zone in the consumer project.
Instance Attribute Summary collapse
-
#consumer_network ⇒ String
Required.
-
#name ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RemoveDnsZoneRequest
constructor
A new instance of RemoveDnsZoneRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RemoveDnsZoneRequest
Returns a new instance of RemoveDnsZoneRequest.
4464 4465 4466 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4464 def initialize(**args) update!(**args) end |
Instance Attribute Details
#consumer_network ⇒ String
Required. The network that the consumer is using to connect with services.
Must be in the form of projects/project/global/networks/network project
is the project number, as in '12345' network is the network name.
Corresponds to the JSON property consumerNetwork
4456 4457 4458 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4456 def consumer_network @consumer_network end |
#name ⇒ String
Required. The name for both the private zone in the shared producer host
project and the peering zone in the consumer project.
Corresponds to the JSON property name
4462 4463 4464 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4462 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4469 4470 4471 4472 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4469 def update!(**args) @consumer_network = args[:consumer_network] if args.key?(:consumer_network) @name = args[:name] if args.key?(:name) end |