Class: Google::Apis::ServicenetworkingV1::SecondaryIpRangeSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicenetworking_v1/classes.rb,
lib/google/apis/servicenetworking_v1/representations.rb,
lib/google/apis/servicenetworking_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecondaryIpRangeSpec

Returns a new instance of SecondaryIpRangeSpec.



4639
4640
4641
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4639

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ip_prefix_lengthFixnum

Required. The prefix length of the secondary IP range. Use CIDR range notation, such as 30 to provision a secondary IP range with an x.x.x.x/30 CIDR range. The IP address range is drawn from a pool of available ranges in the service consumer's allocated range. Corresponds to the JSON property ipPrefixLength

Returns:

  • (Fixnum)


4615
4616
4617
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4615

def ip_prefix_length
  @ip_prefix_length
end

#outside_allocation_public_ip_rangeString

Optional. Enable outside allocation using public IP addresses. Any public IP range may be specified. If this field is provided, we will not use customer reserved ranges for this secondary IP range. Corresponds to the JSON property outsideAllocationPublicIpRange

Returns:

  • (String)


4622
4623
4624
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4622

def outside_allocation_public_ip_range
  @outside_allocation_public_ip_range
end

#range_nameString

Required. A name for the secondary IP range. The name must be 1-63 characters long, and comply with RFC1035. The name must be unique within the subnetwork. Corresponds to the JSON property rangeName

Returns:

  • (String)


4628
4629
4630
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4628

def range_name
  @range_name
end

#requested_addressString

Optional. The starting address of a range. The address must be a valid IPv4 address in the x.x.x.x format. This value combined with the IP prefix range is the CIDR range for the secondary IP range. The range must be within the allocated range that is assigned to the private connection. If the CIDR range isn't available, the call fails. Corresponds to the JSON property requestedAddress

Returns:

  • (String)


4637
4638
4639
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4637

def requested_address
  @requested_address
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4644
4645
4646
4647
4648
4649
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 4644

def update!(**args)
  @ip_prefix_length = args[:ip_prefix_length] if args.key?(:ip_prefix_length)
  @outside_allocation_public_ip_range = args[:outside_allocation_public_ip_range] if args.key?(:outside_allocation_public_ip_range)
  @range_name = args[:range_name] if args.key?(:range_name)
  @requested_address = args[:requested_address] if args.key?(:requested_address)
end