Class: Google::Apis::ServicenetworkingV1::ServiceNetworkingService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::ServicenetworkingV1::ServiceNetworkingService
- Defined in:
- lib/google/apis/servicenetworking_v1/service.rb
Overview
Service Networking API
Provides automatic management of network configurations necessary for certain services.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://servicenetworking.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#add_dns_record_set(parent, add_dns_record_set_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::Operation
Service producers can use this method to add DNS record sets to private DNS zones in the shared producer host project.
-
#add_dns_zone(parent, add_dns_zone_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::Operation
Service producers can use this method to add private DNS zones in the shared producer host project and matching peering zones in the consumer project.
-
#add_roles(parent, add_roles_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::Operation
Service producers can use this method to add roles in the shared VPC host project.
-
#add_service_subnetwork(parent, add_subnetwork_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::Operation
For service producers, provisions a new subnet in a peered service's shared VPC network in the requested region and with the requested size that's expressed as a CIDR range (number of leading bits of ipV4 network mask).
-
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::Empty
Starts asynchronous cancellation on a long-running operation.
-
#create_service_connection(parent, connection_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::Operation
Creates a private connection that establishes a VPC Network Peering connection to a VPC network in the service producer's organization.
-
#create_service_project_global_network_peered_dns_domain(parent, peered_dns_domain_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::Operation
Creates a peered DNS domain which sends requests for records in given namespace originating in the service producer VPC network to the consumer VPC network to be resolved.
-
#delete_connection(name, delete_connection_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::Operation
Deletes a private service access connection.
-
#delete_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::Empty
Deletes a long-running operation.
-
#delete_service_project_global_network_peered_dns_domain(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::Operation
Deletes a peered DNS domain.
-
#disable_vpc_service_controls(parent, disable_vpc_service_controls_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::Operation
Disables VPC service controls for a connection.
-
#enable_vpc_service_controls(parent, enable_vpc_service_controls_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::Operation
Enables VPC service controls for a connection.
-
#get_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::Operation
Gets the latest state of a long-running operation.
-
#get_service_dns_record_set(parent, consumer_network: nil, domain: nil, type: nil, zone: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::DnsRecordSet
Producers can use this method to retrieve information about the DNS record set added to the private zone inside the shared tenant host project associated with a consumer network.
-
#get_service_project_global_network(name, include_used_ip_ranges: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::ConsumerConfig
Service producers use this method to get the configuration of their connection including the import/export of custom routes and subnetwork routes with public IP.
-
#get_service_project_global_network_dns_zone(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::GetDnsZoneResponse
Service producers can use this method to retrieve a DNS zone in the shared producer host project and the matching peering zones in consumer project.
-
#get_service_project_global_network_vpc_service_controls(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::VpcServiceControls
Consumers use this method to find out the state of VPC Service Controls.
-
#initialize ⇒ ServiceNetworkingService
constructor
A new instance of ServiceNetworkingService.
-
#list_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_service_connections(parent, network: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::ListConnectionsResponse
List the private connections that are configured in a service consumer's VPC network.
-
#list_service_dns_record_sets(parent, consumer_network: nil, zone: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::ListDnsRecordSetsResponse
Producers can use this method to retrieve a list of available DNS RecordSets available inside the private zone on the tenant host project accessible from their network.
-
#list_service_project_global_network_dns_zones(parent, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::ListDnsZonesResponse
- Service producers can use this method to retrieve a list of available DNS zones in the shared producer host project and the matching peering zones in the consumer project.
-
#list_service_project_global_network_peered_dns_domains(parent, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::ListPeeredDnsDomainsResponse
Lists peered DNS domains for a connection.
-
#patch_service_connection(name, connection_object = nil, force: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::Operation
Updates the allocated ranges that are assigned to a connection.
-
#remove_dns_record_set(parent, remove_dns_record_set_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::Operation
Service producers can use this method to remove DNS record sets from private DNS zones in the shared producer host project.
-
#remove_dns_zone(parent, remove_dns_zone_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::Operation
Service producers can use this method to remove private DNS zones in the shared producer host project and matching peering zones in the consumer project.
-
#search_service_range(parent, search_range_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::Operation
Service producers can use this method to find a currently unused range within consumer allocated ranges.
-
#update_dns_record_set(parent, update_dns_record_set_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::Operation
Service producers can use this method to update DNS record sets from private DNS zones in the shared producer host project.
-
#update_network_consumer_config(parent, update_consumer_config_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::Operation
Service producers use this method to update the configuration of their connection including the import/export of custom routes and subnetwork routes with public IP.
-
#validate_service_consumer_config(parent, validate_consumer_config_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::ValidateConsumerConfigResponse
Service producers use this method to validate if the consumer provided network, project and requested range are valid.
Constructor Details
#initialize ⇒ ServiceNetworkingService
Returns a new instance of ServiceNetworkingService.
48 49 50 51 52 53 |
# File 'lib/google/apis/servicenetworking_v1/service.rb', line 48 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-servicenetworking_v1', client_version: Google::Apis::ServicenetworkingV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
41 42 43 |
# File 'lib/google/apis/servicenetworking_v1/service.rb', line 41 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
46 47 48 |
# File 'lib/google/apis/servicenetworking_v1/service.rb', line 46 def quota_user @quota_user end |
Instance Method Details
#add_dns_record_set(parent, add_dns_record_set_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::Operation
Service producers can use this method to add DNS record sets to private DNS zones in the shared producer host project.
589 590 591 592 593 594 595 596 597 598 599 |
# File 'lib/google/apis/servicenetworking_v1/service.rb', line 589 def add_dns_record_set(parent, add_dns_record_set_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/dnsRecordSets:add', ) command.request_representation = Google::Apis::ServicenetworkingV1::AddDnsRecordSetRequest::Representation command.request_object = add_dns_record_set_request_object command.response_representation = Google::Apis::ServicenetworkingV1::Operation::Representation command.response_class = Google::Apis::ServicenetworkingV1::Operation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#add_dns_zone(parent, add_dns_zone_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::Operation
Service producers can use this method to add private DNS zones in the shared producer host project and matching peering zones in the consumer project.
787 788 789 790 791 792 793 794 795 796 797 |
# File 'lib/google/apis/servicenetworking_v1/service.rb', line 787 def add_dns_zone(parent, add_dns_zone_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/dnsZones:add', ) command.request_representation = Google::Apis::ServicenetworkingV1::AddDnsZoneRequest::Representation command.request_object = add_dns_zone_request_object command.response_representation = Google::Apis::ServicenetworkingV1::Operation::Representation command.response_class = Google::Apis::ServicenetworkingV1::Operation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#add_roles(parent, add_roles_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::Operation
Service producers can use this method to add roles in the shared VPC host project. Each role is bound to the provided member. Each role must be selected from within an allowlisted set of roles. Each role is applied at only the granularity specified in the allowlist.
1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 |
# File 'lib/google/apis/servicenetworking_v1/service.rb', line 1176 def add_roles(parent, add_roles_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/roles:add', ) command.request_representation = Google::Apis::ServicenetworkingV1::AddRolesRequest::Representation command.request_object = add_roles_request_object command.response_representation = Google::Apis::ServicenetworkingV1::Operation::Representation command.response_class = Google::Apis::ServicenetworkingV1::Operation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#add_service_subnetwork(parent, add_subnetwork_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::Operation
For service producers, provisions a new subnet in a peered service's shared VPC network in the requested region and with the requested size that's expressed as a CIDR range (number of leading bits of ipV4 network mask). The method checks against the assigned allocated ranges to find a non-conflicting IP address range. The method will reuse a subnet if subsequent calls contain the same subnet name, region, and prefix length. This method will make producer's tenant project to be a shared VPC service project as needed.
240 241 242 243 244 245 246 247 248 249 250 |
# File 'lib/google/apis/servicenetworking_v1/service.rb', line 240 def add_service_subnetwork(parent, add_subnetwork_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}:addSubnetwork', ) command.request_representation = Google::Apis::ServicenetworkingV1::AddSubnetworkRequest::Representation command.request_object = add_subnetwork_request_object command.response_representation = Google::Apis::ServicenetworkingV1::Operation::Representation command.response_class = Google::Apis::ServicenetworkingV1::Operation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/google/apis/servicenetworking_v1/service.rb', line 83 def cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:cancel', ) command.request_representation = Google::Apis::ServicenetworkingV1::CancelOperationRequest::Representation command.request_object = cancel_operation_request_object command.response_representation = Google::Apis::ServicenetworkingV1::Empty::Representation command.response_class = Google::Apis::ServicenetworkingV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_service_connection(parent, connection_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::Operation
Creates a private connection that establishes a VPC Network Peering connection to a VPC network in the service producer's organization. The administrator of the service consumer's VPC network invokes this method. The administrator must assign one or more allocated IP ranges for provisioning subnetworks in the service producer's VPC network. This connection is used for all supported services in the service producer's organization, so it only needs to be invoked once.
427 428 429 430 431 432 433 434 435 436 437 |
# File 'lib/google/apis/servicenetworking_v1/service.rb', line 427 def create_service_connection(parent, connection_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/connections', ) command.request_representation = Google::Apis::ServicenetworkingV1::Connection::Representation command.request_object = connection_object command.response_representation = Google::Apis::ServicenetworkingV1::Operation::Representation command.response_class = Google::Apis::ServicenetworkingV1::Operation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_service_project_global_network_peered_dns_domain(parent, peered_dns_domain_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::Operation
Creates a peered DNS domain which sends requests for records in given namespace originating in the service producer VPC network to the consumer VPC network to be resolved.
1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 |
# File 'lib/google/apis/servicenetworking_v1/service.rb', line 1064 def create_service_project_global_network_peered_dns_domain(parent, peered_dns_domain_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/peeredDnsDomains', ) command.request_representation = Google::Apis::ServicenetworkingV1::PeeredDnsDomain::Representation command.request_object = peered_dns_domain_object command.response_representation = Google::Apis::ServicenetworkingV1::Operation::Representation command.response_class = Google::Apis::ServicenetworkingV1::Operation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_connection(name, delete_connection_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::Operation
Deletes a private service access connection.
465 466 467 468 469 470 471 472 473 474 475 |
# File 'lib/google/apis/servicenetworking_v1/service.rb', line 465 def delete_connection(name, delete_connection_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}', ) command.request_representation = Google::Apis::ServicenetworkingV1::DeleteConnectionRequest::Representation command.request_object = delete_connection_request_object command.response_representation = Google::Apis::ServicenetworkingV1::Operation::Representation command.response_class = Google::Apis::ServicenetworkingV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
118 119 120 121 122 123 124 125 126 |
# File 'lib/google/apis/servicenetworking_v1/service.rb', line 118 def delete_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::ServicenetworkingV1::Empty::Representation command.response_class = Google::Apis::ServicenetworkingV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_service_project_global_network_peered_dns_domain(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::Operation
Deletes a peered DNS domain.
1103 1104 1105 1106 1107 1108 1109 1110 1111 |
# File 'lib/google/apis/servicenetworking_v1/service.rb', line 1103 def delete_service_project_global_network_peered_dns_domain(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::ServicenetworkingV1::Operation::Representation command.response_class = Google::Apis::ServicenetworkingV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#disable_vpc_service_controls(parent, disable_vpc_service_controls_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::Operation
Disables VPC service controls for a connection.
275 276 277 278 279 280 281 282 283 284 285 |
# File 'lib/google/apis/servicenetworking_v1/service.rb', line 275 def disable_vpc_service_controls(parent, disable_vpc_service_controls_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+parent}:disableVpcServiceControls', ) command.request_representation = Google::Apis::ServicenetworkingV1::DisableVpcServiceControlsRequest::Representation command.request_object = disable_vpc_service_controls_request_object command.response_representation = Google::Apis::ServicenetworkingV1::Operation::Representation command.response_class = Google::Apis::ServicenetworkingV1::Operation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#enable_vpc_service_controls(parent, enable_vpc_service_controls_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::Operation
Enables VPC service controls for a connection.
310 311 312 313 314 315 316 317 318 319 320 |
# File 'lib/google/apis/servicenetworking_v1/service.rb', line 310 def enable_vpc_service_controls(parent, enable_vpc_service_controls_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+parent}:enableVpcServiceControls', ) command.request_representation = Google::Apis::ServicenetworkingV1::EnableVpcServiceControlsRequest::Representation command.request_object = enable_vpc_service_controls_request_object command.response_representation = Google::Apis::ServicenetworkingV1::Operation::Representation command.response_class = Google::Apis::ServicenetworkingV1::Operation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
149 150 151 152 153 154 155 156 157 |
# File 'lib/google/apis/servicenetworking_v1/service.rb', line 149 def get_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::ServicenetworkingV1::Operation::Representation command.response_class = Google::Apis::ServicenetworkingV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_service_dns_record_set(parent, consumer_network: nil, domain: nil, type: nil, zone: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::DnsRecordSet
Producers can use this method to retrieve information about the DNS record set added to the private zone inside the shared tenant host project associated with a consumer network.
634 635 636 637 638 639 640 641 642 643 644 645 646 |
# File 'lib/google/apis/servicenetworking_v1/service.rb', line 634 def get_service_dns_record_set(parent, consumer_network: nil, domain: nil, type: nil, zone: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/dnsRecordSets:get', ) command.response_representation = Google::Apis::ServicenetworkingV1::DnsRecordSet::Representation command.response_class = Google::Apis::ServicenetworkingV1::DnsRecordSet command.params['parent'] = parent unless parent.nil? command.query['consumerNetwork'] = consumer_network unless consumer_network.nil? command.query['domain'] = domain unless domain.nil? command.query['type'] = type unless type.nil? command.query['zone'] = zone unless zone.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_service_project_global_network(name, include_used_ip_ranges: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::ConsumerConfig
Service producers use this method to get the configuration of their connection including the import/export of custom routes and subnetwork routes with public IP.
870 871 872 873 874 875 876 877 878 879 |
# File 'lib/google/apis/servicenetworking_v1/service.rb', line 870 def get_service_project_global_network(name, include_used_ip_ranges: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::ServicenetworkingV1::ConsumerConfig::Representation command.response_class = Google::Apis::ServicenetworkingV1::ConsumerConfig command.params['name'] = name unless name.nil? command.query['includeUsedIpRanges'] = include_used_ip_ranges unless include_used_ip_ranges.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_service_project_global_network_dns_zone(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::GetDnsZoneResponse
Service producers can use this method to retrieve a DNS zone in the shared producer host project and the matching peering zones in consumer project
986 987 988 989 990 991 992 993 994 |
# File 'lib/google/apis/servicenetworking_v1/service.rb', line 986 def get_service_project_global_network_dns_zone(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::ServicenetworkingV1::GetDnsZoneResponse::Representation command.response_class = Google::Apis::ServicenetworkingV1::GetDnsZoneResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_service_project_global_network_vpc_service_controls(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::VpcServiceControls
Consumers use this method to find out the state of VPC Service Controls. The controls could be enabled or disabled for a connection.
908 909 910 911 912 913 914 915 916 |
# File 'lib/google/apis/servicenetworking_v1/service.rb', line 908 def get_service_project_global_network_vpc_service_controls(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/vpcServiceControls', ) command.response_representation = Google::Apis::ServicenetworkingV1::VpcServiceControls::Representation command.response_class = Google::Apis::ServicenetworkingV1::VpcServiceControls command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/google/apis/servicenetworking_v1/service.rb', line 193 def list_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::ServicenetworkingV1::ListOperationsResponse::Representation command.response_class = Google::Apis::ServicenetworkingV1::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_service_connections(parent, network: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::ListConnectionsResponse
List the private connections that are configured in a service consumer's VPC network.
508 509 510 511 512 513 514 515 516 517 |
# File 'lib/google/apis/servicenetworking_v1/service.rb', line 508 def list_service_connections(parent, network: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/connections', ) command.response_representation = Google::Apis::ServicenetworkingV1::ListConnectionsResponse::Representation command.response_class = Google::Apis::ServicenetworkingV1::ListConnectionsResponse command.params['parent'] = parent unless parent.nil? command.query['network'] = network unless network.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_service_dns_record_sets(parent, consumer_network: nil, zone: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::ListDnsRecordSetsResponse
Producers can use this method to retrieve a list of available DNS RecordSets available inside the private zone on the tenant host project accessible from their network.
679 680 681 682 683 684 685 686 687 688 689 |
# File 'lib/google/apis/servicenetworking_v1/service.rb', line 679 def list_service_dns_record_sets(parent, consumer_network: nil, zone: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/dnsRecordSets:list', ) command.response_representation = Google::Apis::ServicenetworkingV1::ListDnsRecordSetsResponse::Representation command.response_class = Google::Apis::ServicenetworkingV1::ListDnsRecordSetsResponse command.params['parent'] = parent unless parent.nil? command.query['consumerNetwork'] = consumer_network unless consumer_network.nil? command.query['zone'] = zone unless zone.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_service_project_global_network_dns_zones(parent, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::ListDnsZonesResponse
- Service producers can use this method to retrieve a list of available DNS zones in the shared producer host project and the matching peering zones in the consumer project. *
1024 1025 1026 1027 1028 1029 1030 1031 1032 |
# File 'lib/google/apis/servicenetworking_v1/service.rb', line 1024 def list_service_project_global_network_dns_zones(parent, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/dnsZones:list', ) command.response_representation = Google::Apis::ServicenetworkingV1::ListDnsZonesResponse::Representation command.response_class = Google::Apis::ServicenetworkingV1::ListDnsZonesResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_service_project_global_network_peered_dns_domains(parent, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::ListPeeredDnsDomainsResponse
Lists peered DNS domains for a connection.
1140 1141 1142 1143 1144 1145 1146 1147 1148 |
# File 'lib/google/apis/servicenetworking_v1/service.rb', line 1140 def list_service_project_global_network_peered_dns_domains(parent, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/peeredDnsDomains', ) command.response_representation = Google::Apis::ServicenetworkingV1::ListPeeredDnsDomainsResponse::Representation command.response_class = Google::Apis::ServicenetworkingV1::ListPeeredDnsDomainsResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_service_connection(name, connection_object = nil, force: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::Operation
Updates the allocated ranges that are assigned to a connection.
551 552 553 554 555 556 557 558 559 560 561 562 563 |
# File 'lib/google/apis/servicenetworking_v1/service.rb', line 551 def patch_service_connection(name, connection_object = nil, force: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::ServicenetworkingV1::Connection::Representation command.request_object = connection_object command.response_representation = Google::Apis::ServicenetworkingV1::Operation::Representation command.response_class = Google::Apis::ServicenetworkingV1::Operation command.params['name'] = name unless name.nil? command.query['force'] = force unless force.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#remove_dns_record_set(parent, remove_dns_record_set_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::Operation
Service producers can use this method to remove DNS record sets from private DNS zones in the shared producer host project.
715 716 717 718 719 720 721 722 723 724 725 |
# File 'lib/google/apis/servicenetworking_v1/service.rb', line 715 def remove_dns_record_set(parent, remove_dns_record_set_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/dnsRecordSets:remove', ) command.request_representation = Google::Apis::ServicenetworkingV1::RemoveDnsRecordSetRequest::Representation command.request_object = remove_dns_record_set_request_object command.response_representation = Google::Apis::ServicenetworkingV1::Operation::Representation command.response_class = Google::Apis::ServicenetworkingV1::Operation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#remove_dns_zone(parent, remove_dns_zone_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::Operation
Service producers can use this method to remove private DNS zones in the shared producer host project and matching peering zones in the consumer project.
824 825 826 827 828 829 830 831 832 833 834 |
# File 'lib/google/apis/servicenetworking_v1/service.rb', line 824 def remove_dns_zone(parent, remove_dns_zone_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/dnsZones:remove', ) command.request_representation = Google::Apis::ServicenetworkingV1::RemoveDnsZoneRequest::Representation command.request_object = remove_dns_zone_request_object command.response_representation = Google::Apis::ServicenetworkingV1::Operation::Representation command.response_class = Google::Apis::ServicenetworkingV1::Operation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#search_service_range(parent, search_range_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::Operation
Service producers can use this method to find a currently unused range within consumer allocated ranges. This returned range is not reserved, and not guaranteed to remain unused. It will validate previously provided allocated ranges, find non-conflicting sub-range of requested size (expressed in number of leading bits of ipv4 network mask, as in CIDR range notation).
348 349 350 351 352 353 354 355 356 357 358 |
# File 'lib/google/apis/servicenetworking_v1/service.rb', line 348 def search_service_range(parent, search_range_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}:searchRange', ) command.request_representation = Google::Apis::ServicenetworkingV1::SearchRangeRequest::Representation command.request_object = search_range_request_object command.response_representation = Google::Apis::ServicenetworkingV1::Operation::Representation command.response_class = Google::Apis::ServicenetworkingV1::Operation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#update_dns_record_set(parent, update_dns_record_set_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::Operation
Service producers can use this method to update DNS record sets from private DNS zones in the shared producer host project.
751 752 753 754 755 756 757 758 759 760 761 |
# File 'lib/google/apis/servicenetworking_v1/service.rb', line 751 def update_dns_record_set(parent, update_dns_record_set_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/dnsRecordSets:update', ) command.request_representation = Google::Apis::ServicenetworkingV1::UpdateDnsRecordSetRequest::Representation command.request_object = update_dns_record_set_request_object command.response_representation = Google::Apis::ServicenetworkingV1::Operation::Representation command.response_class = Google::Apis::ServicenetworkingV1::Operation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#update_network_consumer_config(parent, update_consumer_config_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::Operation
Service producers use this method to update the configuration of their connection including the import/export of custom routes and subnetwork routes with public IP.
948 949 950 951 952 953 954 955 956 957 958 |
# File 'lib/google/apis/servicenetworking_v1/service.rb', line 948 def update_network_consumer_config(parent, update_consumer_config_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+parent}:updateConsumerConfig', ) command.request_representation = Google::Apis::ServicenetworkingV1::UpdateConsumerConfigRequest::Representation command.request_object = update_consumer_config_request_object command.response_representation = Google::Apis::ServicenetworkingV1::Operation::Representation command.response_class = Google::Apis::ServicenetworkingV1::Operation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#validate_service_consumer_config(parent, validate_consumer_config_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicenetworkingV1::ValidateConsumerConfigResponse
Service producers use this method to validate if the consumer provided network, project and requested range are valid. This allows them to use a fail-fast mechanism for consumer requests, and not have to wait for AddSubnetwork operation completion to determine if user request is invalid.
386 387 388 389 390 391 392 393 394 395 396 |
# File 'lib/google/apis/servicenetworking_v1/service.rb', line 386 def validate_service_consumer_config(parent, validate_consumer_config_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}:validate', ) command.request_representation = Google::Apis::ServicenetworkingV1::ValidateConsumerConfigRequest::Representation command.request_object = validate_consumer_config_request_object command.response_representation = Google::Apis::ServicenetworkingV1::ValidateConsumerConfigResponse::Representation command.response_class = Google::Apis::ServicenetworkingV1::ValidateConsumerConfigResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |