Class: Google::Apis::ServicenetworkingV1::UpdateDnsRecordSetRequest
- Inherits:
-
Object
- Object
- Google::Apis::ServicenetworkingV1::UpdateDnsRecordSetRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicenetworking_v1/classes.rb,
lib/google/apis/servicenetworking_v1/representations.rb,
lib/google/apis/servicenetworking_v1/representations.rb
Overview
Request to update a record set from a private managed DNS zone in the shared producer host project. The name, type, ttl, and data values of the existing record set must all exactly match an existing record set in the specified zone.
Instance Attribute Summary collapse
-
#consumer_network ⇒ String
Required.
-
#existing_dns_record_set ⇒ Google::Apis::ServicenetworkingV1::DnsRecordSet
Represents a DNS record set resource.
-
#new_dns_record_set ⇒ Google::Apis::ServicenetworkingV1::DnsRecordSet
Represents a DNS record set resource.
-
#zone ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpdateDnsRecordSetRequest
constructor
A new instance of UpdateDnsRecordSetRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpdateDnsRecordSetRequest
Returns a new instance of UpdateDnsRecordSetRequest.
5378 5379 5380 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 5378 def initialize(**args) update!(**args) end |
Instance Attribute Details
#consumer_network ⇒ String
Required. The network that the consumer is using to connect with services.
Must be in the form of projects/project/global/networks/network project
is the project number, as in '12345' network is the network name.
Corresponds to the JSON property consumerNetwork
5360 5361 5362 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 5360 def consumer_network @consumer_network end |
#existing_dns_record_set ⇒ Google::Apis::ServicenetworkingV1::DnsRecordSet
Represents a DNS record set resource.
Corresponds to the JSON property existingDnsRecordSet
5365 5366 5367 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 5365 def existing_dns_record_set @existing_dns_record_set end |
#new_dns_record_set ⇒ Google::Apis::ServicenetworkingV1::DnsRecordSet
Represents a DNS record set resource.
Corresponds to the JSON property newDnsRecordSet
5370 5371 5372 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 5370 def new_dns_record_set @new_dns_record_set end |
#zone ⇒ String
Required. The name of the private DNS zone in the shared producer host project
from which the record set will be removed.
Corresponds to the JSON property zone
5376 5377 5378 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 5376 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5383 5384 5385 5386 5387 5388 |
# File 'lib/google/apis/servicenetworking_v1/classes.rb', line 5383 def update!(**args) @consumer_network = args[:consumer_network] if args.key?(:consumer_network) @existing_dns_record_set = args[:existing_dns_record_set] if args.key?(:existing_dns_record_set) @new_dns_record_set = args[:new_dns_record_set] if args.key?(:new_dns_record_set) @zone = args[:zone] if args.key?(:zone) end |